@@ -1,16 +1,19 @@
-import numpy as np
-import logging
-import h5py
-import os
 import json
+import logging
+import os
 from typing import TYPE_CHECKING
 
-from ..version import __version__ as _qcodes_version
+import h5py
+import numpy as np
+
+import qcodes as qc
+from qcodes.utils import NumpyJSONEncoder, deep_update
+
 from .data_array import DataArray
 from .format import Formatter
 
 if TYPE_CHECKING:
-    from .data_set import DataSet
+    import qcodes.data.data_set
 
 class HDF5Format(Formatter):
     """
@@ -22,7 +25,7 @@ class HDF5Format(Formatter):
 
     _format_tag = 'hdf5'
 
-    def close_file(self, data_set: 'DataSet'):
+    def close_file(self, data_set: "qcodes.data.data_set.DataSet"):
         """
         Closes the hdf5 file open in the dataset.
 
@@ -55,7 +58,7 @@ class HDF5Format(Formatter):
                                                 io_manager=data_set.io)
         data_set._h5_base_group = h5py.File(filepath, 'r+')
 
-    def read(self, data_set: 'DataSet', location=None):
+    def read(self, data_set: "qcodes.data.data_set.DataSet", location=None):
         """
         Reads an hdf5 file specified by location into a data_set object.
         If no data_set is provided will create an empty data_set to read into.
@@ -70,6 +73,19 @@ class HDF5Format(Formatter):
             location (None or str): Location to write the data. If no location
                 is provided will use the location specified in the dataset.
         """
+        def decode_bytes_if_needed(s):
+            """
+            h5py 2 stores strings encoded as bytestrings
+            h5py 3 fixes this and stores them as regular utf8 strings
+
+            This is a simple wrapper to always convert to regular strings
+            """
+            try:
+                s = s.decode()
+            except AttributeError:
+                pass
+            return s
+
         self._open_file(data_set, location)
 
         if '__format_tag' in data_set._h5_base_group.attrs:
@@ -85,19 +101,20 @@ class HDF5Format(Formatter):
             dat_arr = data_set._h5_base_group['Data Arrays'][array_id]
 
             # write ensures these attributes always exist
-            name = dat_arr.attrs['name'].decode()
-            label = dat_arr.attrs['label'].decode()
+            name = decode_bytes_if_needed(dat_arr.attrs['name'])
+            label = decode_bytes_if_needed(dat_arr.attrs['label'])
 
             # get unit from units if no unit field, for backward compatibility
             if 'unit' in dat_arr.attrs:
-                unit = dat_arr.attrs['unit'].decode()
+                unit = decode_bytes_if_needed(dat_arr.attrs['unit'])
             else:
-                unit = dat_arr.attrs['units'].decode()
+                unit = decode_bytes_if_needed(dat_arr.attrs['units'])
 
-            is_setpoint = str_to_bool(dat_arr.attrs['is_setpoint'].decode())
+            is_setpoint_str = decode_bytes_if_needed(dat_arr.attrs['is_setpoint'])
+            is_setpoint = str_to_bool(is_setpoint_str)
             # if not is_setpoint:
             set_arrays = dat_arr.attrs['set_arrays']
-            set_arrays = [s.decode() for s in set_arrays]
+            set_arrays = [decode_bytes_if_needed(s) for s in set_arrays]
             # else:
             #     set_arrays = ()
             vals = dat_arr[:, 0]
@@ -150,8 +167,8 @@ class HDF5Format(Formatter):
         # name. This is useful for saving e.g. images in the same folder
         # I think this is a sane default (MAR).
         data_set._h5_base_group = self._create_file(filepath)
-        data_set._h5_base_group.attrs['__qcodes_version'] = _qcodes_version
-        data_set._h5_base_group.attrs['__format_tag'] = self._format_tag
+        data_set._h5_base_group.attrs["__qcodes_version"] = qc.__version__
+        data_set._h5_base_group.attrs["__format_tag"] = self._format_tag
 
         return data_set._h5_base_group
 
@@ -223,8 +240,7 @@ class HDF5Format(Formatter):
                                 datasetshape[1])
             dset.resize(new_datasetshape)
             new_data_shape = (new_dlen - old_dlen, datasetshape[1])
-            dset[old_dlen:new_dlen] = x[old_dlen:new_dlen].reshape(
-                new_data_shape)
+            dset[old_dlen:new_dlen] = x.flat[old_dlen:new_dlen].reshape(new_data_shape)
             # allow resizing extracted data, here so it gets written for
             # incremental writes aswell
             dset.attrs['shape'] = x.shape
@@ -238,13 +254,13 @@ class HDF5Format(Formatter):
             data_set._h5_base_group.file.flush()
 
     def _create_dataarray_dset(self, array, group):
-        '''
+        """
         input arguments
         array:  Dataset data array
         group:  group in the hdf5 file where the dset will be created
 
         creates a hdf5 datasaset that represents the data array.
-        '''
+        """
         # Check for empty meta attributes, use array_id if name and/or label
         # is not specified
         if array.label is not None:
@@ -303,11 +319,11 @@ class HDF5Format(Formatter):
                                  h5_group=entry_point[list_type])
 
         if list_type == 'tuple':
-            item = tuple([d[k] for k in sorted(d.keys())])
+            item = tuple(d[k] for k in sorted(d.keys()))
         elif list_type == 'list':
             item = [d[k] for k in sorted(d.keys())]
         else:
-            raise Exception('type %s not supported' % type(item))
+            raise Exception('type %s not supported' % list_type)
 
         return item
 
@@ -402,7 +418,7 @@ class HDF5Format(Formatter):
                     'storing as string'.format(type(item), key, item))
                 entry_point.attrs[key] = str(item)
 
-    def read_metadata(self, data_set: 'DataSet'):
+    def read_metadata(self, data_set: "qcodes.data.data_set.DataSet"):
         """
         Reads in the metadata, this is also called at the end of a read
         statement so there should be no need to call this explicitly.
@@ -490,15 +506,19 @@ def str_to_bool(s):
         raise ValueError(f"Cannot covert {s} to a bool")
 
 
-from qcodes.utils.helpers import deep_update, NumpyJSONEncoder
-
-
 class HDF5FormatMetadata(HDF5Format):
 
     _format_tag = 'hdf5-json'
     metadata_file = 'snapshot.json'
 
-    def write_metadata(self, data_set: 'DataSet', io_manager=None, location=None, read_first=False, **kwargs):
+    def write_metadata(
+        self,
+        data_set: "qcodes.data.data_set.DataSet",
+        io_manager=None,
+        location=None,
+        read_first=False,
+        **kwargs,
+    ):
         """
         Write all metadata in this DataSet to storage.
 
