@@ -1,14 +1,15 @@
 from __future__ import annotations
 
 import logging
-from typing import TYPE_CHECKING, Dict, Generic, Mapping, Optional, Tuple, TypeVar
+from collections.abc import Mapping
+from typing import TYPE_CHECKING, Generic, TypeVar
 
 import numpy as np
 
 from qcodes.dataset.descriptions.rundescriber import RunDescriber
 from qcodes.dataset.sqlite.connection import ConnectionPlus
 from qcodes.dataset.sqlite.queries import completed, load_new_data_for_rundescriber
-from qcodes.utils.deprecate import deprecate
+from qcodes.utils import deprecate
 
 from .exporters.export_to_pandas import (
     load_to_concatenated_dataframe,
@@ -48,18 +49,18 @@ class DataSetCache(Generic[DatasetType]):
         self._dataset = dataset
         self._data: ParameterData = {}
         #: number of rows read per parameter tree (by the name of the dependent parameter)
-        self._read_status: Dict[str, int] = {}
+        self._read_status: dict[str, int] = {}
         #: number of rows written per parameter tree (by the name of the dependent parameter)
-        self._write_status: Dict[str, Optional[int]] = {}
+        self._write_status: dict[str, int | None] = {}
         self._loaded_from_completed_ds = False
-        self._live: Optional[bool] = None
+        self._live: bool | None = None
 
     @property
     def rundescriber(self) -> RunDescriber:
         return self._dataset.description
 
     @property
-    def live(self) -> Optional[bool]:
+    def live(self) -> bool | None:
         """
         If true this cache has been produced by appending data as measured.
         If false the data has been read from disk.
@@ -130,7 +131,7 @@ class DataSetCache(Generic[DatasetType]):
         if not all(status is None for status in self._write_status.values()):
             self._live = True
 
-    def to_pandas_dataframe_dict(self) -> Dict[str, pd.DataFrame]:
+    def to_pandas_dataframe_dict(self) -> dict[str, pd.DataFrame]:
         """
         Convert the cached dataset to Pandas dataframes. The returned dataframes
         are in the same format :py:class:`.DataSet.to_pandas_dataframe_dict`.
@@ -155,7 +156,7 @@ class DataSetCache(Generic[DatasetType]):
         return load_to_concatenated_dataframe(data)
 
     @deprecate(alternative="to_pandas_dataframe or to_pandas_dataframe_dict")
-    def to_pandas(self) -> Dict[str, pd.DataFrame]:
+    def to_pandas(self) -> dict[str, pd.DataFrame]:
         """
         Returns the values stored in the :class:`.dataset.data_set.DataSet` as a
         concatenated :py:class:`pandas.DataFrame` s
@@ -175,7 +176,7 @@ class DataSetCache(Generic[DatasetType]):
         """
         return self.to_pandas_dataframe_dict()
 
-    def to_xarray_dataarray_dict(self) -> Dict[str, xr.DataArray]:
+    def to_xarray_dataarray_dict(self) -> dict[str, xr.DataArray]:
         """
         Returns the values stored in the :class:`.dataset.data_set.DataSet` as a dict of
         :py:class:`xr.DataArray` s
@@ -212,10 +213,10 @@ def load_new_data_from_db_and_append(
     conn: ConnectionPlus,
     table_name: str,
     rundescriber: RunDescriber,
-    write_status: Mapping[str, Optional[int]],
+    write_status: Mapping[str, int | None],
     read_status: Mapping[str, int],
     existing_data: Mapping[str, Mapping[str, np.ndarray]],
-) -> Tuple[Dict[str, Optional[int]], Dict[str, int], Dict[str, Dict[str, np.ndarray]]]:
+) -> tuple[dict[str, int | None], dict[str, int], dict[str, dict[str, np.ndarray]]]:
     """
     Append any new data in the db to an already existing datadict and return the merged
     data.
@@ -253,10 +254,10 @@ def load_new_data_from_db_and_append(
 
 def append_shaped_parameter_data_to_existing_arrays(
     rundescriber: RunDescriber,
-    write_status: Mapping[str, Optional[int]],
+    write_status: Mapping[str, int | None],
     existing_data: Mapping[str, Mapping[str, np.ndarray]],
     new_data: Mapping[str, Mapping[str, np.ndarray]],
-) -> Tuple[Dict[str, Optional[int]], Dict[str, Dict[str, np.ndarray]]]:
+) -> tuple[dict[str, int | None], dict[str, dict[str, np.ndarray]]]:
     """
     Append datadict to an already existing datadict and return the merged
     data.
@@ -303,12 +304,13 @@ def append_shaped_parameter_data_to_existing_arrays(
     return updated_write_status, merged_data
 
 
-def _merge_data(existing_data: Mapping[str, np.ndarray],
-                new_data: Mapping[str, np.ndarray],
-                shape: Optional[Tuple[int, ...]],
-                single_tree_write_status: Optional[int],
-                meas_parameter: str,
-                ) -> Tuple[Dict[str, np.ndarray], Optional[int]]:
+def _merge_data(
+    existing_data: Mapping[str, np.ndarray],
+    new_data: Mapping[str, np.ndarray],
+    shape: tuple[int, ...] | None,
+    single_tree_write_status: int | None,
+    meas_parameter: str,
+) -> tuple[dict[str, np.ndarray], int | None]:
 
     subtree_merged_data = {}
     subtree_parameters = existing_data.keys()
@@ -320,7 +322,7 @@ def _merge_data(existing_data: Mapping[str, np.ndarray],
             f"{set(new_data.keys() - existing_data.keys())}"
         )
 
-    new_write_status: Optional[int]
+    new_write_status: int | None
     single_param_merged_data, new_write_status = _merge_data_single_param(
         existing_data.get(meas_parameter),
         new_data.get(meas_parameter),
@@ -346,11 +348,12 @@ def _merge_data(existing_data: Mapping[str, np.ndarray],
 
 
 def _merge_data_single_param(
-        existing_values: Optional[np.ndarray],
-        new_values: Optional[np.ndarray],
-        shape: Optional[Tuple[int, ...]],
-        single_tree_write_status: Optional[int]) -> Tuple[Optional[np.ndarray], Optional[int]]:
-    merged_data: Optional[np.ndarray]
+    existing_values: np.ndarray | None,
+    new_values: np.ndarray | None,
+    shape: tuple[int, ...] | None,
+    single_tree_write_status: int | None,
+) -> tuple[np.ndarray | None, int | None]:
+    merged_data: np.ndarray | None
     if (
         existing_values is not None and existing_values.size != 0
     ) and new_values is not None:
@@ -372,9 +375,9 @@ def _merge_data_single_param(
     return merged_data, new_write_status
 
 
-def _create_new_data_dict(new_values: np.ndarray,
-                          shape: Optional[Tuple[int, ...]]
-                          ) -> Tuple[np.ndarray, int]:
+def _create_new_data_dict(
+    new_values: np.ndarray, shape: tuple[int, ...] | None
+) -> tuple[np.ndarray, int]:
     if shape is None:
         return new_values, new_values.size
     elif new_values.size > 0:
@@ -393,11 +396,11 @@ def _create_new_data_dict(new_values: np.ndarray,
 
 
 def _insert_into_data_dict(
-        existing_values: np.ndarray,
-        new_values: np.ndarray,
-        write_status: Optional[int],
-        shape: Optional[Tuple[int, ...]]
-) -> Tuple[np.ndarray, Optional[int]]:
+    existing_values: np.ndarray,
+    new_values: np.ndarray,
+    write_status: int | None,
+    shape: tuple[int, ...] | None,
+) -> tuple[np.ndarray, int | None]:
     if new_values.size == 0:
         return existing_values, write_status
 
@@ -439,7 +442,7 @@ def _insert_into_data_dict(
 
 def _expand_single_param_dict(
         single_param_dict: Mapping[str, np.ndarray]
-) -> Dict[str, np.ndarray]:
+) -> dict[str, np.ndarray]:
     sizes = {name: array.size for name, array in single_param_dict.items()}
     maxsize = max(sizes.values())
     max_names = tuple(name for name, size in sizes.items() if size == maxsize)
