@@ -3,10 +3,10 @@ The measurement module provides a context manager for registering parameters
 to measure and storing results. The user is expected to mainly interact with it
 using the :class:`.Measurement` class.
 """
+from __future__ import annotations
 
-
+import collections
 import io
-import json
 import logging
 import traceback as tb_module
 import warnings
@@ -15,31 +15,57 @@ from inspect import signature
 from numbers import Number
 from time import perf_counter
 from types import TracebackType
-from typing import (Any, Callable, Dict, List, Mapping, MutableMapping,
-                    MutableSequence, Optional, Sequence, Tuple, Type, TypeVar,
-                    Union, cast)
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Sequence,
+    Tuple,
+    TypeVar,
+    Union,
+    cast,
+)
 
 import numpy as np
 
 import qcodes as qc
-import qcodes.utils.validators as vals
-from qcodes import Station
-from qcodes.dataset.data_set import (VALUE, DataSet, load_by_guid, res_type,
-                                     setpoints_type, values_type)
-from qcodes.dataset.descriptions.dependencies import (DependencyError,
-                                                      InferenceError,
-                                                      InterDependencies_)
+import qcodes.validators as vals
+from qcodes.dataset.data_set import VALUE, DataSet, load_by_guid
+from qcodes.dataset.data_set_in_memory import DataSetInMem
+from qcodes.dataset.data_set_protocol import (
+    DataSetProtocol,
+    DataSetType,
+    res_type,
+    setpoints_type,
+    values_type,
+)
+from qcodes.dataset.descriptions.dependencies import (
+    DependencyError,
+    InferenceError,
+    InterDependencies_,
+)
 from qcodes.dataset.descriptions.param_spec import ParamSpec, ParamSpecBase
 from qcodes.dataset.descriptions.rundescriber import RunDescriber
 from qcodes.dataset.descriptions.versioning.rundescribertypes import Shapes
 from qcodes.dataset.experiment_container import Experiment
-from qcodes.dataset.linked_datasets.links import Link
-from qcodes.instrument.parameter import (ArrayParameter, MultiParameter,
-                                         Parameter, ParameterWithSetpoints,
-                                         _BaseParameter,
-                                         expand_setpoints_helper)
-from qcodes.utils.delaykeyboardinterrupt import DelayedKeyboardInterrupt
-from qcodes.utils.helpers import NumpyJSONEncoder
+from qcodes.dataset.export_config import get_data_export_automatic
+from qcodes.parameters import (
+    ArrayParameter,
+    GroupedParameter,
+    MultiParameter,
+    Parameter,
+    ParameterBase,
+    ParameterWithSetpoints,
+    expand_setpoints_helper,
+)
+from qcodes.station import Station
+from qcodes.utils import DelayedKeyboardInterrupt
+
+if TYPE_CHECKING:
+    from qcodes.dataset.sqlite.connection import ConnectionPlus
 
 log = logging.getLogger(__name__)
 
@@ -60,40 +86,46 @@ class DataSaver:
     datasaving to the database.
     """
 
-    default_callback: Optional[Dict[Any,Any]] = None
+    default_callback: dict[Any, Any] | None = None
 
-    def __init__(self, dataset: DataSet,
-                 write_period: float,
-                 interdeps: InterDependencies_) -> None:
+    def __init__(
+        self,
+        dataset: DataSetProtocol,
+        write_period: float,
+        interdeps: InterDependencies_,
+    ) -> None:
         self._dataset = dataset
-        if DataSaver.default_callback is not None \
-                and 'run_tables_subscription_callback' \
-                    in DataSaver.default_callback:
-            callback = DataSaver.default_callback[
-                'run_tables_subscription_callback']
-            min_wait = DataSaver.default_callback[
-                'run_tables_subscription_min_wait']
-            min_count = DataSaver.default_callback[
-                'run_tables_subscription_min_count']
-            snapshot = dataset.get_metadata('snapshot')
-            self._dataset.subscribe(callback,
-                                    min_wait=min_wait,
-                                    min_count=min_count,
-                                    state={},
-                                    callback_kwargs={'run_id':
-                                                     self._dataset.run_id,
-                                                     'snapshot': snapshot})
-        default_subscribers = qc.config.subscription.default_subscribers
-        for subscriber in default_subscribers:
-            self._dataset.subscribe_from_config(subscriber)
+        if (
+            DataSaver.default_callback is not None
+            and "run_tables_subscription_callback" in DataSaver.default_callback
+        ):
+            callback = DataSaver.default_callback["run_tables_subscription_callback"]
+            min_wait = DataSaver.default_callback["run_tables_subscription_min_wait"]
+            min_count = DataSaver.default_callback["run_tables_subscription_min_count"]
+            snapshot = dataset.metadata["snapshot"]
+            if isinstance(self._dataset, DataSet):
+                self._dataset.subscribe(
+                    callback,
+                    min_wait=min_wait,
+                    min_count=min_count,
+                    state={},
+                    callback_kwargs={
+                        "run_id": self._dataset.run_id,
+                        "snapshot": snapshot,
+                    },
+                )
+        if isinstance(self._dataset, DataSet):
+            default_subscribers = qc.config.subscription.default_subscribers
+            for subscriber in default_subscribers:
+                self._dataset.subscribe_from_config(subscriber)
 
         self._interdeps = interdeps
         self.write_period = float(write_period)
         # self._results will be filled by add_result
-        self._results: List[Dict[str, VALUE]] = []
+        self._results: list[dict[str, VALUE]] = []
         self._last_save_time = perf_counter()
-        self._known_dependencies: Dict[str, List[str]] = {}
-        self.parent_datasets: List[DataSet] = []
+        self._known_dependencies: dict[str, list[str]] = {}
+        self.parent_datasets: list[DataSetProtocol] = []
 
         for link in self._dataset.parent_dataset_links:
             self.parent_datasets.append(load_by_guid(link.tail))
@@ -125,6 +157,7 @@ class DataSaver:
             ValueError: If the shapes of parameters do not match, i.e. if a
                 parameter gets values of a different shape than its setpoints
                 (the exception being that setpoints can always be scalar)
+            ValueError: If multiple results are given for the same parameter.
             ParameterTypeError: If a parameter is given a value not matching
                 its type.
         """
@@ -134,18 +167,32 @@ class DataSaver:
         # of all parameters. This also allows users to call
         # add_result with the arguments in any particular order, i.e. NOT
         # enforcing that setpoints come before dependent variables.
-        results_dict: Dict[ParamSpecBase, np.ndarray] = {}
+        results_dict: dict[ParamSpecBase, np.ndarray] = {}
 
-        parameter_names = tuple(partial_result[0].full_name
-                                if isinstance(partial_result[0], _BaseParameter) else partial_result[0]
-                                for partial_result in res_tuple)
+        parameter_names = tuple(
+            partial_result[0].full_name
+            if isinstance(partial_result[0], ParameterBase)
+            else partial_result[0]
+            for partial_result in res_tuple
+        )
+        if len(set(parameter_names)) != len(parameter_names):
+            non_unique = [
+                item
+                for item, count in collections.Counter(parameter_names).items()
+                if count > 1
+            ]
+            raise ValueError(
+                f"Not all parameter names are unique. "
+                f"Got multiple values for {non_unique}"
+            )
 
         for partial_result in res_tuple:
             parameter = partial_result[0]
             data = partial_result[1]
 
-            if (isinstance(parameter, _BaseParameter) and
-                    isinstance(parameter.vals, vals.Arrays)):
+            if isinstance(parameter, ParameterBase) and isinstance(
+                parameter.vals, vals.Arrays
+            ):
                 if not isinstance(data, np.ndarray):
                     raise TypeError(
                         f"Expected data for Parameter with Array validator "
@@ -154,8 +201,8 @@ class DataSaver:
                 if (parameter.vals.shape is not None
                         and data.shape != parameter.vals.shape):
                     raise TypeError(
-                        "Expected data with shape {parameter.vals.shape}, "
-                        "but got {data.shape}"
+                        f"Expected data with shape {parameter.vals.shape}, "
+                        f"but got {data.shape} for parameter: {parameter.full_name}"
                     )
 
             if isinstance(parameter, ArrayParameter):
@@ -188,7 +235,7 @@ class DataSaver:
     def _conditionally_expand_parameter_with_setpoints(
             self, data: values_type, parameter: ParameterWithSetpoints,
             parameter_names: Sequence[str], partial_result: res_type
-    ) -> Dict[ParamSpecBase, np.ndarray]:
+    ) -> dict[ParamSpecBase, np.ndarray]:
         local_results = {}
         setpoint_names = tuple(setpoint.full_name for setpoint in parameter.setpoints)
         expanded = tuple(setpoint_name in parameter_names for setpoint_name in setpoint_names)
@@ -208,8 +255,8 @@ class DataSaver:
         return local_results
 
     def _unpack_partial_result(
-            self,
-            partial_result: res_type) -> Dict[ParamSpecBase, np.ndarray]:
+        self, partial_result: res_type
+    ) -> dict[ParamSpecBase, np.ndarray]:
         """
         Unpack a partial result (not containing :class:`ArrayParameters` or
         class:`MultiParameters`) into a standard results dict form and return
@@ -225,7 +272,8 @@ class DataSaver:
         return {parameter: np.array(values)}
 
     def _unpack_arrayparameter(
-        self, partial_result: res_type) -> Dict[ParamSpecBase, np.ndarray]:
+        self, partial_result: res_type
+    ) -> dict[ParamSpecBase, np.ndarray]:
         """
         Unpack a partial result containing an :class:`Arrayparameter` into a
         standard results dict form and return that dict
@@ -257,7 +305,8 @@ class DataSaver:
         return res_dict
 
     def _unpack_multiparameter(
-            self, partial_result: res_type) -> Dict[ParamSpecBase, np.ndarray]:
+        self, partial_result: res_type
+    ) -> dict[ParamSpecBase, np.ndarray]:
         """
         Unpack the `subarrays` and `setpoints` from a :class:`MultiParameter`
         and into a standard results dict form and return that dict
@@ -293,7 +342,7 @@ class DataSaver:
                 # need to find setpoints too
                 fallback_sp_name = f'{parameter.full_names[i]}_setpoint'
 
-                sp_names: Optional[Sequence[str]]
+                sp_names: Sequence[str] | None
                 if (parameter.setpoint_full_names is not None
                         and parameter.setpoint_full_names[i] is not None):
                     sp_names = parameter.setpoint_full_names[i]
@@ -310,16 +359,19 @@ class DataSaver:
         return result_dict
 
     def _unpack_setpoints_from_parameter(
-        self, parameter: _BaseParameter, setpoints: Sequence[Any],
-        sp_names: Optional[Sequence[str]], fallback_sp_name: str
-            ) -> Dict[ParamSpecBase, np.ndarray]:
+        self,
+        parameter: ParameterBase,
+        setpoints: Sequence[Any],
+        sp_names: Sequence[str] | None,
+        fallback_sp_name: str,
+    ) -> dict[ParamSpecBase, np.ndarray]:
         """
         Unpack the `setpoints` and their values from a
         :class:`ArrayParameter` or :class:`MultiParameter`
         into a standard results dict form and return that dict
         """
         setpoint_axes = []
-        setpoint_parameters: List[ParamSpecBase] = []
+        setpoint_parameters: list[ParamSpecBase] = []
 
         for i, sps in enumerate(setpoints):
             if sp_names is not None:
@@ -373,10 +425,10 @@ class DataSaver:
         toplevel_params = (set(self._interdeps.dependencies)
                            .intersection(set(results_dict)))
         for toplevel_param in toplevel_params:
-            required_shape = np.shape(results_dict[toplevel_param])
+            required_shape = np.shape(np.array(results_dict[toplevel_param]))
             for setpoint in self._interdeps.dependencies[toplevel_param]:
                 # a setpoint is allowed to be a scalar; shape is then ()
-                setpoint_shape = np.shape(results_dict[setpoint])
+                setpoint_shape = np.shape(np.array(results_dict[setpoint]))
                 if setpoint_shape not in [(), required_shape]:
                     raise ValueError(f'Incompatible shapes. Parameter '
                                      f"{toplevel_param.name} has shape "
@@ -412,6 +464,12 @@ class DataSaver:
         """
         self.dataset._flush_data_to_database(block=block)
 
+    def export_data(self) -> None:
+        """Export data at end of measurement as per export_type
+        specification in "dataset" section of qcodes config
+        """
+        self.dataset.export()
+
     @property
     def run_id(self) -> int:
         return self._dataset.run_id
@@ -421,7 +479,7 @@ class DataSaver:
         return self._dataset.number_of_results
 
     @property
-    def dataset(self) -> DataSet:
+    def dataset(self) -> DataSetProtocol:
         return self._dataset
 
 
@@ -438,20 +496,24 @@ class Runner:
     """
 
     def __init__(
-            self,
-            enteractions:  List[ActionType],
-            exitactions: List[ActionType],
-            experiment: Optional[Experiment] = None,
-            station: Optional[Station] = None,
-            write_period: Optional[float] = None,
-            interdeps: InterDependencies_ = InterDependencies_(),
-            name: str = '',
-            subscribers: Optional[Sequence[SubscriberType]] = None,
-            parent_datasets: Sequence[Dict[Any, Any]] = (),
-            extra_log_info: str = '',
-            write_in_background: bool = False,
-            shapes: Optional[Shapes] = None) -> None:
+        self,
+        enteractions: Sequence[ActionType],
+        exitactions: Sequence[ActionType],
+        experiment: Experiment | None = None,
+        station: Station | None = None,
+        write_period: float | None = None,
+        interdeps: InterDependencies_ = InterDependencies_(),
+        name: str = "",
+        subscribers: Sequence[SubscriberType] | None = None,
+        parent_datasets: Sequence[Mapping[Any, Any]] = (),
+        extra_log_info: str = "",
+        write_in_background: bool = False,
+        shapes: Shapes | None = None,
+        in_memory_cache: bool = True,
+        dataset_class: DataSetType = DataSetType.DataSet,
+    ) -> None:
 
+        self._dataset_class = dataset_class
         self.write_period = self._calculate_write_period(write_in_background,
                                                          write_period)
 
@@ -465,16 +527,17 @@ class Runner:
         self.experiment = experiment
         self.station = station
         self._interdependencies = interdeps
-        self._shapes: Shapes = shapes
+        self._shapes: Shapes | None = shapes
         self.name = name if name else 'results'
         self._parent_datasets = parent_datasets
         self._extra_log_info = extra_log_info
         self._write_in_background = write_in_background
+        self._in_memory_cache = in_memory_cache
+        self.ds: DataSetProtocol
 
     @staticmethod
     def _calculate_write_period(
-            write_in_background: bool,
-            write_period: Optional[float]
+        write_in_background: bool, write_period: float | None
     ) -> float:
         write_period_changed_from_default = (
                 write_period is not None and
@@ -496,48 +559,79 @@ class Runner:
         for func, args in self.enteractions:
             func(*args)
 
+        dataset_class: type[DataSetProtocol]
+
         # next set up the "datasaver"
         if self.experiment is not None:
-            self.ds = qc.new_data_set(
-                self.name, self.experiment.exp_id, conn=self.experiment.conn
+            exp_id: int | None = self.experiment.exp_id
+            path_to_db: str | None = self.experiment.path_to_db
+            conn: ConnectionPlus | None = self.experiment.conn
+        else:
+            exp_id = None
+            path_to_db = None
+            conn = None
+
+        if self._dataset_class is DataSetType.DataSet:
+            self.ds = DataSet(
+                name=self.name,
+                exp_id=exp_id,
+                conn=conn,
+                in_memory_cache=self._in_memory_cache,
+            )
+        elif self._dataset_class is DataSetType.DataSetInMem:
+            if self._in_memory_cache is False:
+                raise RuntimeError(
+                    "Cannot disable the in memory cache for a "
+                    "dataset that is only in memory."
+                )
+            self.ds = DataSetInMem._create_new_run(
+                name=self.name,
+                exp_id=exp_id,
+                path_to_db=path_to_db,
             )
         else:
-            self.ds = qc.new_data_set(self.name)
+            raise RuntimeError("Does not support any other dataset classes")
 
         # .. and give the dataset a snapshot as metadata
         if self.station is None:
-            station = qc.Station.default
+            station = Station.default
         else:
             station = self.station
 
-        if station:
-            self.ds.add_snapshot(json.dumps({'station': station.snapshot()},
-                                            cls=NumpyJSONEncoder))
-
-        if self._interdependencies == InterDependencies_():
-            raise RuntimeError("No parameters supplied")
+        if station is not None:
+            snapshot = station.snapshot()
         else:
-            self.ds.set_interdependencies(self._interdependencies,
-                                          self._shapes)
+            snapshot = {}
 
-        links = [Link(head=self.ds.guid, **pdict)
-                 for pdict in self._parent_datasets]
-        self.ds.parent_dataset_links = links
-        self.ds.mark_started(start_bg_writer=self._write_in_background)
+        self.ds.prepare(
+            snapshot=snapshot,
+            interdeps=self._interdependencies,
+            write_in_background=self._write_in_background,
+            shapes=self._shapes,
+            parent_datasets=self._parent_datasets,
+        )
 
         # register all subscribers
-        for (callble, state) in self.subscribers:
-            # We register with minimal waiting time.
-            # That should make all subscribers be called when data is flushed
-            # to the database
-            log.debug(f'Subscribing callable {callble} with state {state}')
-            self.ds.subscribe(callble, min_wait=0, min_count=1, state=state)
+        if isinstance(self.ds, DataSet):
+            for (callble, state) in self.subscribers:
+                # We register with minimal waiting time.
+                # That should make all subscribers be called when data is flushed
+                # to the database
+                log.debug(f"Subscribing callable {callble} with state {state}")
+                self.ds.subscribe(callble, min_wait=0, min_count=1, state=state)
 
-        print(f'Starting experimental run with id: {self.ds.run_id}.'
-              f' {self._extra_log_info}')
-        log.info(f'Starting measurement with guid: {self.ds.guid}.'
-                 f' {self._extra_log_info}')
-        log.info(f'Using background writing: {self._write_in_background}')
+        print(
+            f"Starting experimental run with id: {self.ds.captured_run_id}."
+            f" {self._extra_log_info}"
+        )
+        log.info(
+            f"Starting measurement with guid: {self.ds.guid}, "
+            f'sample_name: "{self.ds.sample_name}", '
+            f'exp_name: "{self.ds.exp_name}", '
+            f'ds_name: "{self.ds.name}". '
+            f"{self._extra_log_info}"
+        )
+        log.info(f"Using background writing: {self._write_in_background}")
 
         self.datasaver = DataSaver(
                             dataset=self.ds,
@@ -546,11 +640,12 @@ class Runner:
 
         return self.datasaver
 
-    def __exit__(self,
-                 exception_type: Optional[Type[BaseException]],
-                 exception_value: Optional[BaseException],
-                 traceback: Optional[TracebackType]
-                 ) -> None:
+    def __exit__(
+        self,
+        exception_type: type[BaseException] | None,
+        exception_value: BaseException | None,
+        traceback: TracebackType | None,
+    ) -> None:
         with DelayedKeyboardInterrupt():
             self.datasaver.flush_data_to_database(block=True)
 
@@ -576,9 +671,12 @@ class Runner:
             # Note that the completion of a dataset entails waiting for the
             # write thread to terminate (iff the write thread has been started)
             self.ds.mark_completed()
+            if get_data_export_automatic():
+                self.datasaver.export_data()
             log.info(f'Finished measurement with guid: {self.ds.guid}. '
                      f'{self._extra_log_info}')
-            self.ds.unsubscribe_all()
+            if isinstance(self.ds, DataSet):
+                self.ds.unsubscribe_all()
 
 
 T = TypeVar('T', bound='Measurement')
@@ -600,24 +698,27 @@ class Measurement:
             'results' is used for the dataset.
     """
 
-    def __init__(self, exp: Optional[Experiment] = None,
-                 station: Optional[qc.Station] = None,
-                 name: str = '') -> None:
-        self.exitactions: List[ActionType] = []
-        self.enteractions: List[ActionType] = []
-        self.subscribers: List[SubscriberType] = []
+    def __init__(
+        self,
+        exp: Experiment | None = None,
+        station: Station | None = None,
+        name: str = "",
+    ) -> None:
+        self.exitactions: list[ActionType] = []
+        self.enteractions: list[ActionType] = []
+        self.subscribers: list[SubscriberType] = []
 
         self.experiment = exp
         self.station = station
         self.name = name
         self.write_period: float = qc.config.dataset.write_period
         self._interdeps = InterDependencies_()
-        self._shapes: Shapes = None
-        self._parent_datasets: List[Dict[str, str]] = []
+        self._shapes: Shapes | None = None
+        self._parent_datasets: list[dict[str, str]] = []
         self._extra_log_info: str = ''
 
     @property
-    def parameters(self) -> Dict[str, ParamSpecBase]:
+    def parameters(self) -> dict[str, ParamSpecBase]:
         return deepcopy(self._interdeps._id_to_paramspec)
 
     @property
@@ -634,9 +735,11 @@ class Measurement:
         self._write_period = wp_float
 
     def _paramspecbase_from_strings(
-            self, name: str, setpoints: Optional[Sequence[str]] = None,
-            basis: Optional[Sequence[str]] = None
-            ) -> Tuple[Tuple[ParamSpecBase, ...], Tuple[ParamSpecBase, ...]]:
+        self,
+        name: str,
+        setpoints: Sequence[str] | None = None,
+        basis: Sequence[str] | None = None,
+    ) -> tuple[tuple[ParamSpecBase, ...], tuple[ParamSpecBase, ...]]:
         """
         Helper function to look up and get ParamSpecBases and to give a nice
         error message if the user tries to register a parameter with reference
@@ -678,8 +781,8 @@ class Measurement:
         return tuple(depends_on), tuple(inf_from)
 
     def register_parent(
-            self: T, parent: DataSet, link_type: str,
-            description: str = "") -> T:
+        self: T, parent: DataSetProtocol, link_type: str, description: str = ""
+    ) -> T:
         """
         Register a parent for the outcome of this measurement
 
@@ -699,10 +802,12 @@ class Measurement:
         return self
 
     def register_parameter(
-            self: T, parameter: _BaseParameter,
-            setpoints: Optional[setpoints_type] = None,
-            basis: Optional[setpoints_type] = None,
-            paramtype: Optional[str] = None) -> T:
+        self: T,
+        parameter: ParameterBase,
+        setpoints: setpoints_type | None = None,
+        basis: setpoints_type | None = None,
+        paramtype: str | None = None,
+    ) -> T:
         """
         Add QCoDeS Parameter to the dataset produced by running this
         measurement.
@@ -719,7 +824,7 @@ class Measurement:
                 If None the paramtype will be inferred from the parameter type
                 and the validator of the supplied parameter.
         """
-        if not isinstance(parameter, _BaseParameter):
+        if not isinstance(parameter, ParameterBase):
             raise ValueError('Can not register object of type {}. Can only '
                              'register a QCoDeS Parameter.'
                              ''.format(type(parameter)))
@@ -757,6 +862,12 @@ class Measurement:
                                      parameter.unit,
                                      setpoints,
                                      basis, paramtype)
+        elif isinstance(parameter, GroupedParameter):
+            self._register_parameter(parameter.full_name,
+                                     parameter.label,
+                                     parameter.unit,
+                                     setpoints,
+                                     basis, paramtype)
         else:
             raise RuntimeError("Does not know how to register a parameter"
                                f"of type {type(parameter)}")
@@ -764,8 +875,7 @@ class Measurement:
         return self
 
     @staticmethod
-    def _infer_paramtype(parameter: _BaseParameter,
-                         paramtype: Optional[str]) -> Optional[str]:
+    def _infer_paramtype(parameter: ParameterBase, paramtype: str | None) -> str | None:
         """
         Infer the best parameter type to store the parameter supplied.
 
@@ -793,17 +903,20 @@ class Measurement:
         # arrays or something else?
         return paramtype
 
-    def _register_parameter(self: T, name: str,
-                            label: Optional[str],
-                            unit: Optional[str],
-                            setpoints: Optional[setpoints_type],
-                            basis: Optional[setpoints_type],
-                            paramtype: str) -> T:
+    def _register_parameter(
+        self: T,
+        name: str,
+        label: str | None,
+        unit: str | None,
+        setpoints: setpoints_type | None,
+        basis: setpoints_type | None,
+        paramtype: str,
+    ) -> T:
         """
         Update the interdependencies object with a new group
         """
 
-        parameter: Optional[ParamSpecBase]
+        parameter: ParamSpecBase | None
 
         try:
             parameter = self._interdeps[name]
@@ -852,11 +965,13 @@ class Measurement:
 
         return self
 
-    def _register_arrayparameter(self,
-                                 parameter: ArrayParameter,
-                                 setpoints: Optional[setpoints_type],
-                                 basis: Optional[setpoints_type],
-                                 paramtype: str, ) -> None:
+    def _register_arrayparameter(
+        self,
+        parameter: ArrayParameter,
+        setpoints: setpoints_type | None,
+        basis: setpoints_type | None,
+        paramtype: str,
+    ) -> None:
         """
         Register an ArrayParameter and the setpoints belonging to that
         ArrayParameter
@@ -893,11 +1008,13 @@ class Measurement:
                                  basis,
                                  paramtype)
 
-    def _register_parameter_with_setpoints(self,
-                                           parameter: ParameterWithSetpoints,
-                                           setpoints: Optional[setpoints_type],
-                                           basis: Optional[setpoints_type],
-                                           paramtype: str) -> None:
+    def _register_parameter_with_setpoints(
+        self,
+        parameter: ParameterWithSetpoints,
+        setpoints: setpoints_type | None,
+        basis: setpoints_type | None,
+        paramtype: str,
+    ) -> None:
         """
         Register an ParameterWithSetpoints and the setpoints belonging to the
         Parameter
@@ -928,11 +1045,13 @@ class Measurement:
                                  basis,
                                  paramtype)
 
-    def _register_multiparameter(self,
-                                 multiparameter: MultiParameter,
-                                 setpoints: Optional[setpoints_type],
-                                 basis: Optional[setpoints_type],
-                                 paramtype: str) -> None:
+    def _register_multiparameter(
+        self,
+        multiparameter: MultiParameter,
+        setpoints: setpoints_type | None,
+        basis: setpoints_type | None,
+        paramtype: str,
+    ) -> None:
         """
         Find the individual multiparameter components and their setpoints
         and register those as individual parameters
@@ -982,11 +1101,14 @@ class Measurement:
                                      paramtype)
 
     def register_custom_parameter(
-            self: T, name: str,
-            label: Optional[str] = None, unit: Optional[str] = None,
-            basis: Optional[setpoints_type] = None,
-            setpoints: Optional[setpoints_type] = None,
-            paramtype: str = 'numeric') -> T:
+        self: T,
+        name: str,
+        label: str | None = None,
+        unit: str | None = None,
+        basis: setpoints_type | None = None,
+        setpoints: setpoints_type | None = None,
+        paramtype: str = "numeric",
+    ) -> T:
         """
         Register a custom parameter with this measurement
 
@@ -1017,7 +1139,7 @@ class Measurement:
         Remove a custom/QCoDeS parameter from the dataset produced by
         running this measurement
         """
-        if isinstance(parameter, _BaseParameter):
+        if isinstance(parameter, ParameterBase):
             param = str(parameter)
         elif isinstance(parameter, str):
             param = parameter
@@ -1072,9 +1194,9 @@ class Measurement:
         return self
 
     def add_subscriber(
-            self: T,
-            func: Callable[..., Any],
-            state: Union[MutableSequence[Any], MutableMapping[Any, Any]]
+        self: T,
+        func: Callable[..., Any],
+        state: MutableSequence[Any] | MutableMapping[Any, Any],
     ) -> T:
         """
         Add a subscriber to the dataset of the measurement.
@@ -1089,7 +1211,7 @@ class Measurement:
 
         return self
 
-    def set_shapes(self, shapes: Shapes) -> None:
+    def set_shapes(self, shapes: Shapes | None) -> None:
         """
         Set the shapes of the data to be recorded in this
         measurement.
@@ -1098,11 +1220,14 @@ class Measurement:
             shapes: Dictionary from names of dependent parameters to a tuple
                 of integers describing the shape of the measurement.
         """
-        RunDescriber._verify_interdeps_shape(interdeps=self._interdeps,
-                                             shapes=shapes)
         self._shapes = shapes
 
-    def run(self, write_in_background: Optional[bool] = None) -> Runner:
+    def run(
+        self,
+        write_in_background: bool | None = None,
+        in_memory_cache: bool = True,
+        dataset_class: DataSetType = DataSetType.DataSet,
+    ) -> Runner:
         """
         Returns the context manager for the experimental run
 
@@ -1113,16 +1238,26 @@ class Measurement:
                 main thread that is executing the context manager.
                 By default the setting for write in background will be
                 read from the ``qcodesrc.json`` config file.
+            in_memory_cache: Should measured data be keep in memory
+                and available as part of the `dataset.cache` object.
+            dataset_class: Enum representing the Class used to store data
+                with.
         """
         if write_in_background is None:
             write_in_background = qc.config.dataset.write_in_background
-        return Runner(self.enteractions, self.exitactions,
-                      self.experiment, station=self.station,
-                      write_period=self._write_period,
-                      interdeps=self._interdeps,
-                      name=self.name,
-                      subscribers=self.subscribers,
-                      parent_datasets=self._parent_datasets,
-                      extra_log_info=self._extra_log_info,
-                      write_in_background=write_in_background,
-                      shapes=self._shapes)
+        return Runner(
+            self.enteractions,
+            self.exitactions,
+            self.experiment,
+            station=self.station,
+            write_period=self._write_period,
+            interdeps=self._interdeps,
+            name=self.name,
+            subscribers=self.subscribers,
+            parent_datasets=self._parent_datasets,
+            extra_log_info=self._extra_log_info,
+            write_in_background=write_in_background,
+            shapes=self._shapes,
+            in_memory_cache=in_memory_cache,
+            dataset_class=dataset_class,
+        )
