@@ -2,23 +2,27 @@
 This plotting module provides various functions to plot the data measured
 using QCoDeS.
 """
+from __future__ import annotations
 
 import inspect
 import logging
+import os
 from contextlib import contextmanager
 from functools import partial
-from typing import Any, List, Optional, Sequence, Tuple, Union, cast
+from typing import Any, List, Optional, Sequence, Tuple, cast
 
 import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
+from matplotlib.axes import Axes
+from matplotlib.colorbar import Colorbar
 from matplotlib.ticker import FuncFormatter
 from typing_extensions import Literal
 
 import qcodes as qc
 from qcodes.dataset.data_set import load_by_run_spec
 from qcodes.dataset.data_set_protocol import DataSetProtocol
-from qcodes.utils.plotting import auto_color_scale_from_config, find_scale_and_prefix
+from qcodes.plotting import auto_color_scale_from_config, find_scale_and_prefix
 
 from .data_export import (
     DSPlotData,
@@ -32,9 +36,8 @@ from .data_export import (
 log = logging.getLogger(__name__)
 DB = qc.config["core"]["db_location"]
 
-AxesTuple = Tuple[matplotlib.axes.Axes, matplotlib.colorbar.Colorbar]
-AxesTupleList = Tuple[List[matplotlib.axes.Axes],
-                      List[Optional[matplotlib.colorbar.Colorbar]]]
+AxesTuple = Tuple[Axes, Colorbar]
+AxesTupleList = Tuple[List[Axes], List[Optional[Colorbar]]]
 # NamedData is the structure _get_data_from_ds returns and that plot_by_id
 # uses internally
 NamedData = List[List[DSPlotData]]
@@ -93,13 +96,11 @@ def _appropriate_kwargs(plottype: str,
 
 def plot_dataset(
     dataset: DataSetProtocol,
-    axes: Optional[Union[matplotlib.axes.Axes, Sequence[matplotlib.axes.Axes]]] = None,
-    colorbars: Optional[
-        Union[matplotlib.colorbar.Colorbar, Sequence[matplotlib.colorbar.Colorbar]]
-    ] = None,
+    axes: Axes | Sequence[Axes] | None = None,
+    colorbars: Colorbar | Sequence[Colorbar] | None = None,
     rescale_axes: bool = True,
-    auto_color_scale: Optional[bool] = None,
-    cutoff_percentile: Optional[Union[Tuple[float, float], float]] = None,
+    auto_color_scale: bool | None = None,
+    cutoff_percentile: tuple[float, float] | float | None = None,
     complex_plot_type: Literal["real_and_imag", "mag_and_phase"] = "real_and_imag",
     complex_plot_phase: Literal["radians", "degrees"] = "radians",
     **kwargs: Any,
@@ -108,6 +109,7 @@ def plot_dataset(
     Construct all plots for a given dataset
 
     Implemented so far:
+
        * 1D line and scatter plots
        * 2D plots on filled out rectangular grids
        * 2D scatterplots (fallback)
@@ -188,11 +190,11 @@ def plot_dataset(
 
     nplots = len(alldata)
 
-    if isinstance(axes, matplotlib.axes.Axes):
+    if isinstance(axes, Axes):
         axeslist = [axes]
     else:
-        axeslist = cast(List[matplotlib.axes.Axes], axes)
-    if isinstance(colorbars, matplotlib.colorbar.Colorbar):
+        axeslist = cast(List[Axes], axes)
+    if isinstance(colorbars, Colorbar):
         colorbars = [colorbars]
 
     if axeslist is None:
@@ -212,7 +214,7 @@ def plot_dataset(
 
     if colorbars is None:
         colorbars = len(axeslist)*[None]
-    new_colorbars: List[matplotlib.colorbar.Colorbar] = []
+    new_colorbars: list[Colorbar] = []
 
     for data, ax, colorbar in zip(alldata, axeslist, colorbars):
 
@@ -306,15 +308,49 @@ def plot_dataset(
     return axeslist, new_colorbars
 
 
+def plot_and_save_image(
+    data: DataSetProtocol, save_pdf: bool = True, save_png: bool = True
+) -> tuple[DataSetProtocol, list[Axes], list[Colorbar | None],]:
+    """
+    The utility function to plot results and save the figures either in pdf or
+    png or both formats.
+
+    Args:
+        data: The QCoDeS dataset to be plotted.
+        save_pdf: Save figure in pdf format.
+        save_png: Save figure in png format.
+    """
+    from qcodes import config
+
+    dataid = data.captured_run_id
+    axes, cbs = plot_dataset(data)
+    mainfolder = config.user.mainfolder
+    experiment_name = data.exp_name
+    sample_name = data.sample_name
+    storage_dir = os.path.join(mainfolder, experiment_name, sample_name)
+    os.makedirs(storage_dir, exist_ok=True)
+    png_dir = os.path.join(storage_dir, "png")
+    pdf_dif = os.path.join(storage_dir, "pdf")
+    os.makedirs(png_dir, exist_ok=True)
+    os.makedirs(pdf_dif, exist_ok=True)
+    for i, ax in enumerate(axes):
+        if save_pdf:
+            full_path = os.path.join(pdf_dif, f"{dataid}_{i}.pdf")
+            ax.figure.savefig(full_path, dpi=500, bbox_inches="tight")
+        if save_png:
+            full_path = os.path.join(png_dir, f"{dataid}_{i}.png")
+            ax.figure.savefig(full_path, dpi=500, bbox_inches="tight")
+    res = data, axes, cbs
+    return res
+
+
 def plot_by_id(
     run_id: int,
-    axes: Optional[Union[matplotlib.axes.Axes, Sequence[matplotlib.axes.Axes]]] = None,
-    colorbars: Optional[
-        Union[matplotlib.colorbar.Colorbar, Sequence[matplotlib.colorbar.Colorbar]]
-    ] = None,
+    axes: Axes | Sequence[Axes] | None = None,
+    colorbars: Colorbar | Sequence[Colorbar] | None = None,
     rescale_axes: bool = True,
-    auto_color_scale: Optional[bool] = None,
-    cutoff_percentile: Optional[Union[Tuple[float, float], float]] = None,
+    auto_color_scale: bool | None = None,
+    cutoff_percentile: tuple[float, float] | float | None = None,
     complex_plot_type: Literal["real_and_imag", "mag_and_phase"] = "real_and_imag",
     complex_plot_phase: Literal["radians", "degrees"] = "radians",
     **kwargs: Any,
@@ -409,7 +445,7 @@ def _complex_to_real_preparser(
 
 def _convert_complex_to_real(
     parameter: DSPlotData, conversion: str, degrees: bool
-) -> Tuple[DSPlotData, DSPlotData]:
+) -> tuple[DSPlotData, DSPlotData]:
     """
     Do the actual conversion and turn one parameter into two.
     Should only be called from within _complex_to_real_preparser.
@@ -471,9 +507,9 @@ def _make_label_for_data_axis(data: Sequence[DSPlotData], axis_index: int) -> st
 
 
 def _set_data_axes_labels(
-    ax: matplotlib.axes.Axes,
+    ax: Axes,
     data: Sequence[DSPlotData],
-    cax: Optional[matplotlib.colorbar.Colorbar] = None,
+    cax: Colorbar | None = None,
 ) -> None:
     ax.set_xlabel(_make_label_for_data_axis(data, 0))
     ax.set_ylabel(_make_label_for_data_axis(data, 1))
@@ -482,10 +518,14 @@ def _set_data_axes_labels(
         cax.set_label(_make_label_for_data_axis(data, 2))
 
 
-def plot_2d_scatterplot(x: np.ndarray, y: np.ndarray, z: np.ndarray,
-                        ax: matplotlib.axes.Axes,
-                        colorbar: matplotlib.colorbar.Colorbar = None,
-                        **kwargs: Any) -> AxesTuple:
+def plot_2d_scatterplot(
+    x: np.ndarray,
+    y: np.ndarray,
+    z: np.ndarray,
+    ax: Axes,
+    colorbar: Colorbar = None,
+    **kwargs: Any,
+) -> AxesTuple:
     """
     Make a 2D scatterplot of the data. ``**kwargs`` are passed to matplotlib's
     scatter used for the plotting. By default the data will be rasterized
@@ -536,13 +576,14 @@ def plot_2d_scatterplot(x: np.ndarray, y: np.ndarray, z: np.ndarray,
     return ax, colorbar
 
 
-def plot_on_a_plain_grid(x: np.ndarray,
-                         y: np.ndarray,
-                         z: np.ndarray,
-                         ax: matplotlib.axes.Axes,
-                         colorbar: matplotlib.colorbar.Colorbar = None,
-                         **kwargs: Any
-                         ) -> AxesTuple:
+def plot_on_a_plain_grid(
+    x: np.ndarray,
+    y: np.ndarray,
+    z: np.ndarray,
+    ax: Axes,
+    colorbar: Colorbar = None,
+    **kwargs: Any,
+) -> AxesTuple:
     """
     Plot a heatmap of z using x and y as axes. Assumes that the data
     are rectangular, i.e. that x and y together describe a rectangular
@@ -643,7 +684,7 @@ def plot_on_a_plain_grid(x: np.ndarray,
 
 def _clip_nan_from_shaped_data(
     x: np.ndarray, y: np.ndarray, z: np.ndarray
-) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
+) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
     def _on_rectilinear_grid_except_nan(x_data: np.ndarray, y_data: np.ndarray) -> bool:
         """
         check that data is on a rectilinear grid. e.g. all points are the same as the  first
@@ -695,7 +736,7 @@ def _scale_formatter(tick_value: float, pos: int, factor: float) -> str:
 
 def _make_rescaled_ticks_and_units(
     data_dict: DSPlotData,
-) -> Tuple[matplotlib.ticker.FuncFormatter, str]:
+) -> tuple[matplotlib.ticker.FuncFormatter, str]:
     """
     Create a ticks formatter and a new label for the data that is to be used
     on the axes where the data is plotted.
@@ -740,9 +781,9 @@ def _make_rescaled_ticks_and_units(
 
 
 def _rescale_ticks_and_units(
-    ax: matplotlib.axes.Axes,
+    ax: Axes,
     data: Sequence[DSPlotData],
-    cax: matplotlib.colorbar.Colorbar = None,
+    cax: Colorbar | None = None,
 ) -> None:
     """
     Rescale ticks and units for the provided axes as described in
