@@ -1,34 +1,23 @@
 """ Base class for the channel of an instrument """
-import sys
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    Generic,
-    Iterable,
-    List,
-    MutableSequence,
-    Optional,
-    Sequence,
-    Tuple,
-    Type,
-    TypeVar,
-    Union,
-    cast,
-    overload,
-)
+from __future__ import annotations
 
-from ..utils.helpers import full_class
-from ..utils.metadata import Metadatable
-from ..utils.validators import Validator
-from .base import Instrument, InstrumentBase
-from .parameter import (
+import sys
+from collections.abc import Callable, Iterable, Iterator
+from typing import Any, List, MutableSequence, Sequence, TypeVar, Union, cast, overload
+
+from qcodes.metadatable import Metadatable
+from qcodes.parameters import (
     ArrayParameter,
-    Iterator,
+    MultiChannelInstrumentParameter,
     MultiParameter,
     Parameter,
-    ParamRawDataType,
 )
+from qcodes.parameters.multi_channel_instrument_parameter import InstrumentModuleType
+from qcodes.utils import full_class
+from qcodes.validators import Validator
+
+from .instrument import Instrument
+from .instrument_base import InstrumentBase
 
 
 class InstrumentModule(InstrumentBase):
@@ -88,8 +77,8 @@ class InstrumentModule(InstrumentBase):
         return self._parent.root_instrument
 
     @property
-    def name_parts(self) -> List[str]:
-        name_parts = self._parent.name_parts
+    def name_parts(self) -> list[str]:
+        name_parts = list(self._parent.name_parts)
         name_parts.append(self.short_name)
         return name_parts
 
@@ -98,71 +87,16 @@ class InstrumentChannel(InstrumentModule):
     pass
 
 
-InstrumentModuleType = TypeVar("InstrumentModuleType", bound="InstrumentModule")
 T = TypeVar("T", bound="ChannelTuple")
 
 
-class MultiChannelInstrumentParameter(MultiParameter, Generic[InstrumentModuleType]):
-    """
-    Parameter to get or set multiple channels simultaneously.
-
-    Will normally be created by a :class:`ChannelList` and not directly by
-    anything else.
-
-    Args:
-        channels: A list of channels which we can operate on
-          simultaneously.
-        param_name: Name of the multichannel parameter
-    """
-
-    def __init__(
-        self,
-        channels: Sequence[InstrumentModuleType],
-        param_name: str,
-        *args: Any,
-        **kwargs: Any,
-    ) -> None:
-        super().__init__(*args, **kwargs)
-        self._channels = channels
-        self._param_name = param_name
-
-    def get_raw(self) -> Tuple[ParamRawDataType, ...]:
-        """
-        Return a tuple containing the data from each of the channels in the
-        list.
-        """
-        return tuple(chan.parameters[self._param_name].get() for chan
-                     in self._channels)
-
-    def set_raw(self, value: ParamRawDataType) -> None:
-        """
-        Set all parameters to this value.
-
-        Args:
-            value: The value to set to. The type is given by the
-                underlying parameter.
-        """
-        for chan in self._channels:
-            getattr(chan, self._param_name).set(value)
-
-    @property
-    def full_names(self) -> Tuple[str, ...]:
-        """
-        Overwrite full_names because the instrument name is already included
-        in the name. This happens because the instrument name is included in
-        the channel name merged into the parameter name above.
-        """
-
-        return self.names
-
-
 class ChannelTuple(Metadatable, Sequence[InstrumentModuleType]):
     """
     Container for channelized parameters that allows for sweeps over
     all channels, as well as addressing of individual channels.
 
     This behaves like a python tuple i.e. it implements the
-    ``collections.abc.Sequence`` interface.
+    :class:`collections.abc.Sequence` interface.
 
     Args:
         parent: The instrument to which this ChannelTuple
@@ -182,15 +116,17 @@ class ChannelTuple(Metadatable, Sequence[InstrumentModuleType]):
             ways and should not be repeated in an instrument snapshot.
 
         multichan_paramclass: The class of
-            the object to be returned by the ``__getattr__``
+            the object to be returned by the :meth:`__getattr__`
             method of :class:`ChannelTuple`.
-            Should be a subclass of :class:`MultiChannelInstrumentParameter`.
+            Should be a subclass of :class:`.MultiChannelInstrumentParameter`.
+            Defaults to :class:`.MultiChannelInstrumentParameter` if None.
+
 
     Raises:
         ValueError: If ``chan_type`` is not a subclass of
             :class:`InstrumentChannel`
         ValueError: If ``multichan_paramclass`` is not a subclass of
-            :class:`MultiChannelInstrumentParameter` (note that a class is a
+            :class:`.MultiChannelInstrumentParameter` (note that a class is a
             subclass of itself).
 
     """
@@ -199,11 +135,14 @@ class ChannelTuple(Metadatable, Sequence[InstrumentModuleType]):
         self,
         parent: InstrumentBase,
         name: str,
-        chan_type: Type[InstrumentModuleType],
-        chan_list: Optional[Sequence[InstrumentModuleType]] = None,
+        chan_type: type[InstrumentModuleType],
+        chan_list: Sequence[InstrumentModuleType] | None = None,
         snapshotable: bool = True,
-        multichan_paramclass: type = MultiChannelInstrumentParameter,
+        multichan_paramclass: type[MultiChannelInstrumentParameter] | None = None,
     ):
+        if multichan_paramclass is None:
+            multichan_paramclass = MultiChannelInstrumentParameter
+
         super().__init__()
 
         self._parent = parent
@@ -226,11 +165,11 @@ class ChannelTuple(Metadatable, Sequence[InstrumentModuleType]):
         self._snapshotable = snapshotable
         self._paramclass = multichan_paramclass
 
-        self._channel_mapping: Dict[str, InstrumentModuleType] = {}
+        self._channel_mapping: dict[str, InstrumentModuleType] = {}
         # provide lookup of channels by name
         # If a list of channels is not provided, define a list to store
         # channels. This will eventually become a locked tuple.
-        self._channels: List[InstrumentModuleType]
+        self._channels: list[InstrumentModuleType]
         if chan_list is None:
             self._channels = []
         else:
@@ -244,16 +183,16 @@ class ChannelTuple(Metadatable, Sequence[InstrumentModuleType]):
                 )
 
     @overload
-    def __getitem__(self, i: int) -> "InstrumentModuleType":
+    def __getitem__(self, i: int) -> InstrumentModuleType:
         ...
 
     @overload
-    def __getitem__(self: T, i: Union[slice, Tuple[int, ...]]) -> T:
+    def __getitem__(self: T, i: slice | tuple[int, ...]) -> T:
         ...
 
     def __getitem__(
-        self: T, i: Union[int, slice, Tuple[int, ...]]
-    ) -> Union[InstrumentModuleType, T]:
+        self: T, i: int | slice | tuple[int, ...]
+    ) -> InstrumentModuleType | T:
         """
         Return either a single channel, or a new :class:`ChannelTuple`
         containing only the specified channels
@@ -282,10 +221,10 @@ class ChannelTuple(Metadatable, Sequence[InstrumentModuleType]):
             )
         return self._channels[i]
 
-    def __iter__(self) -> Iterator["InstrumentModuleType"]:
+    def __iter__(self) -> Iterator[InstrumentModuleType]:
         return iter(self._channels)
 
-    def __reversed__(self) -> Iterator["InstrumentModuleType"]:
+    def __reversed__(self) -> Iterator[InstrumentModuleType]:
         return reversed(self._channels)
 
     def __len__(self) -> int:
@@ -300,7 +239,7 @@ class ChannelTuple(Metadatable, Sequence[InstrumentModuleType]):
             f"{self._chan_type.__name__}, {self._channels!r})"
         )
 
-    def __add__(self: T, other: "ChannelTuple") -> T:
+    def __add__(self: T, other: ChannelTuple) -> T:
         """
         Return a new ChannelTuple containing the channels from both
         :class:`ChannelTuple` self and r.
@@ -355,7 +294,7 @@ class ChannelTuple(Metadatable, Sequence[InstrumentModuleType]):
         """
         return self._channels.count(obj)
 
-    def get_channel_by_name(self: T, *names: str) -> Union[InstrumentModuleType, T]:
+    def get_channel_by_name(self: T, *names: str) -> InstrumentModuleType | T:
         """
         Get a channel by name, or a ChannelTuple if multiple names are given.
 
@@ -376,20 +315,22 @@ class ChannelTuple(Metadatable, Sequence[InstrumentModuleType]):
             self._paramclass,
         )
 
-    def get_validator(self) -> "ChannelTupleValidator":
+    def get_validator(self) -> ChannelTupleValidator:
         """
         Returns a validator that checks that the returned object is a channel
         in this ChannelTuple
         """
         return ChannelTupleValidator(self)
 
-    def snapshot_base(self, update: Optional[bool] = True,
-                      params_to_skip_update: Optional[Sequence[str]] = None
-                      ) -> Dict[Any, Any]:
+    def snapshot_base(
+        self,
+        update: bool | None = True,
+        params_to_skip_update: Sequence[str] | None = None,
+    ) -> dict[Any, Any]:
         """
         State of the instrument as a JSON-compatible dict (everything that
         the custom JSON encoder class
-        :class:`qcodes.utils.helpers.NumpyJSONEncoder` supports).
+        :class:`.NumpyJSONEncoder` supports).
 
         Args:
             update: If True, update the state by querying the
@@ -420,9 +361,7 @@ class ChannelTuple(Metadatable, Sequence[InstrumentModuleType]):
 
     def __getattr__(
         self, name: str
-    ) -> Union[
-        MultiChannelInstrumentParameter, Callable[..., None], InstrumentModuleType
-    ]:
+    ) -> (MultiChannelInstrumentParameter | Callable[..., None] | InstrumentModuleType):
         """
         Look up an attribute by name. If this is the name of a parameter or
         a function on the channel type contained in this container return a
@@ -430,12 +369,12 @@ class ChannelTuple(Metadatable, Sequence[InstrumentModuleType]):
         set all items in a channel list simultaneously. If this is the
         name of a channel, return that channel.
 
-        Params:
+        Args:
             name: The name of the parameter, function or channel that we want to
-            operate on.
+                operate on.
         """
-        # Check if this is a valid parameter
         if len(self) > 0:
+            # Check if this is a valid parameter
             if name in self._channels[0].parameters:
                 param = self._construct_multiparam(name)
                 return param
@@ -450,6 +389,17 @@ class ChannelTuple(Metadatable, Sequence[InstrumentModuleType]):
 
                 return multi_func
 
+            # check if this is a method on the channels in the
+            # sequence
+            maybe_callable = getattr(self._channels[0], name, None)
+            if callable(maybe_callable):
+
+                def multi_callable(*args: Any) -> None:
+                    for chan in self._channels:
+                        getattr(chan, name)(*args)
+
+                return multi_callable
+
         try:
             return self._channel_mapping[name]
         except KeyError:
@@ -514,7 +464,7 @@ class ChannelTuple(Metadatable, Sequence[InstrumentModuleType]):
         )
         return param
 
-    def __dir__(self) -> List[Any]:
+    def __dir__(self) -> list[Any]:
         names = list(super().__dir__())
         if self._channels:
             names += list(self._channels[0].parameters.keys())
@@ -545,18 +495,18 @@ class ChannelList(ChannelTuple, MutableSequence[InstrumentModuleType]):  # type:
     all channels, as well as addressing of individual channels.
 
     This behaves like a python list i.e. it implements the
-    ``collections.abc.MutableSequence`` interface.
+    :class:`collections.abc.MutableSequence` interface.
 
     Note it may be useful to use the mutable ChannelList while constructing it.
     E.g. adding channels as they are created, but in most use cases it is recommended
-    to convert this to a ``ChannelTuple`` before adding it to an instrument.
-    This can be done using the ``to_channel_tuple`` method.
+    to convert this to a :class:`ChannelTuple` before adding it to an instrument.
+    This can be done using the :meth:`to_channel_tuple` method.
 
     Args:
-        parent: The instrument to which this ChannelList
+        parent: The instrument to which this :class:`ChannelList`
             should be attached.
 
-        name: The name of the ChannelList.
+        name: The name of the :class:`ChannelList`.
 
         chan_type: The type of channel contained
             within this list.
@@ -571,15 +521,16 @@ class ChannelList(ChannelTuple, MutableSequence[InstrumentModuleType]):  # type:
             ways and should not be repeated in an instrument snapshot.
 
         multichan_paramclass: The class of
-            the object to be returned by the ``__getattr__``
+            the object to be returned by the :meth:`__getattr__`
             method of :class:`ChannelList`.
-            Should be a subclass of :class:`MultiChannelInstrumentParameter`.
+            Should be a subclass of :class:`.MultiChannelInstrumentParameter`.
+            Defaults to :class:`.MultiChannelInstrumentParameter` if None.
 
     Raises:
         ValueError: If ``chan_type`` is not a subclass of
             :class:`InstrumentChannel`
         ValueError: If ``multichan_paramclass`` is not a subclass of
-            :class:`MultiChannelInstrumentParameter` (note that a class is a
+            :class:`.MultiChannelInstrumentParameter` (note that a class is a
             subclass of itself).
 
     """
@@ -588,11 +539,13 @@ class ChannelList(ChannelTuple, MutableSequence[InstrumentModuleType]):  # type:
         self,
         parent: InstrumentBase,
         name: str,
-        chan_type: Type[InstrumentModuleType],
-        chan_list: Optional[Sequence[InstrumentModuleType]] = None,
+        chan_type: type[InstrumentModuleType],
+        chan_list: Sequence[InstrumentModuleType] | None = None,
         snapshotable: bool = True,
-        multichan_paramclass: type = MultiChannelInstrumentParameter,
+        multichan_paramclass: type[MultiChannelInstrumentParameter] | None = None,
     ):
+        if multichan_paramclass is None:
+            multichan_paramclass = MultiChannelInstrumentParameter
         super().__init__(
             parent, name, chan_type, chan_list, snapshotable, multichan_paramclass
         )
@@ -609,7 +562,7 @@ class ChannelList(ChannelTuple, MutableSequence[InstrumentModuleType]):  # type:
     def __delitem__(self, key: slice) -> None:
         ...
 
-    def __delitem__(self, key: Union[int, slice]) -> None:
+    def __delitem__(self, key: int | slice) -> None:
         if self._locked:
             raise AttributeError("Cannot delete from a locked channel list")
         self._channels.__delitem__(key)
@@ -627,8 +580,8 @@ class ChannelList(ChannelTuple, MutableSequence[InstrumentModuleType]):  # type:
 
     def __setitem__(
         self,
-        index: Union[int, slice],
-        value: Union[InstrumentModuleType, Iterable[InstrumentModuleType]],
+        index: int | slice,
+        value: InstrumentModuleType | Iterable[InstrumentModuleType],
     ) -> None:
         if self._locked:
             raise AttributeError("Cannot set item in a locked channel list")
@@ -722,7 +675,7 @@ class ChannelList(ChannelTuple, MutableSequence[InstrumentModuleType]):  # type:
         self._channels.insert(index, obj)
         self._channel_mapping[obj.short_name] = obj
 
-    def get_validator(self) -> "ChannelTupleValidator":
+    def get_validator(self) -> ChannelTupleValidator:
         """
         Returns a validator that checks that the returned object is a channel
         in this ChannelList.
@@ -831,10 +784,11 @@ class AutoLoadableInstrumentChannel(InstrumentChannel):
 
     @classmethod
     def load_from_instrument(
-            cls, parent: Instrument,
-            channel_list: Optional['AutoLoadableChannelList'] = None,
-            **kwargs: Any
-    ) -> List['AutoLoadableInstrumentChannel']:
+        cls,
+        parent: Instrument,
+        channel_list: AutoLoadableChannelList | None = None,
+        **kwargs: Any,
+    ) -> list[AutoLoadableInstrumentChannel]:
         """
         Load channels that already exist on the instrument
 
@@ -862,7 +816,8 @@ class AutoLoadableInstrumentChannel(InstrumentChannel):
 
     @classmethod
     def _discover_from_instrument(
-            cls, parent: Instrument, **kwargs: Any) -> List[Dict[Any, Any]]:
+        cls, parent: Instrument, **kwargs: Any
+    ) -> list[dict[Any, Any]]:
         """
         Discover channels on the instrument and return a list kwargs to create
         these channels in memory
@@ -881,10 +836,12 @@ class AutoLoadableInstrumentChannel(InstrumentChannel):
 
     @classmethod
     def new_instance(
-            cls, parent: Instrument, create_on_instrument: bool = True,
-            channel_list: Optional['AutoLoadableChannelList'] = None,
-            **kwargs: Any
-    ) -> 'AutoLoadableInstrumentChannel':
+        cls,
+        parent: Instrument,
+        create_on_instrument: bool = True,
+        channel_list: AutoLoadableChannelList | None = None,
+        **kwargs: Any,
+    ) -> AutoLoadableInstrumentChannel:
         """
         Create a new instance of the channel on the instrument: This involves
         finding initialization arguments which will create a channel with a
@@ -929,8 +886,9 @@ class AutoLoadableInstrumentChannel(InstrumentChannel):
         return new_instance
 
     @classmethod
-    def _get_new_instance_kwargs(cls, parent: Optional[Instrument] = None,
-                                 **kwargs: Any) -> Dict[Any, Any]:
+    def _get_new_instance_kwargs(
+        cls, parent: Instrument | None = None, **kwargs: Any
+    ) -> dict[Any, Any]:
         """
         Returns a dictionary which is used as keyword args when instantiating a
         channel
@@ -958,12 +916,13 @@ class AutoLoadableInstrumentChannel(InstrumentChannel):
             "Please subclass and implement this method in the subclass")
 
     def __init__(
-            self,
-            parent: Union[Instrument, 'InstrumentChannel'],
-            name: str,
-            exists_on_instrument: bool = False,
-            channel_list: Optional['AutoLoadableChannelList'] = None,
-            **kwargs: Any):
+        self,
+        parent: Instrument | InstrumentChannel,
+        name: str,
+        exists_on_instrument: bool = False,
+        channel_list: AutoLoadableChannelList | None = None,
+        **kwargs: Any,
+    ):
         """
         Instantiate a channel object. Note that this is not the same as actually
         creating the channel on the instrument. Parameters defined on this
@@ -1081,14 +1040,14 @@ class AutoLoadableChannelList(ChannelList):
             subclass of itself).
     """
     def __init__(
-            self,
-            parent: Instrument,
-            name: str,
-            chan_type: type,
-            chan_list: Optional[Sequence['AutoLoadableInstrumentChannel']] = None,
-            snapshotable: bool = True,
-            multichan_paramclass: type = MultiChannelInstrumentParameter,
-            **kwargs: Any
+        self,
+        parent: Instrument,
+        name: str,
+        chan_type: type,
+        chan_list: Sequence[AutoLoadableInstrumentChannel] | None = None,
+        snapshotable: bool = True,
+        multichan_paramclass: type = MultiChannelInstrumentParameter,
+        **kwargs: Any,
     ) -> None:
 
         super().__init__(
@@ -1100,7 +1059,7 @@ class AutoLoadableChannelList(ChannelList):
 
         self.extend(new_channels)
 
-    def add(self, **kwargs: Any) -> 'AutoLoadableInstrumentChannel':
+    def add(self, **kwargs: Any) -> AutoLoadableInstrumentChannel:
         """
         Add a channel to the list
 
