@@ -1,14 +1,14 @@
-from distutils.version import LooseVersion
 from typing import Any
 
 import numpy as np
+from packaging import version
 
+from qcodes import validators
 from qcodes.instrument_drivers.AlazarTech.ATS import AlazarTech_ATS
 from qcodes.instrument_drivers.AlazarTech.utils import TraceParameter
-from qcodes.utils import validators
 
 
-class AlazarTech_ATS9373(AlazarTech_ATS):
+class AlazarTechATS9373(AlazarTech_ATS):
     """
     This class is the driver for the ATS9373 board.
 
@@ -340,9 +340,10 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
                             f" found '{str(model)}' instead.")
 
     def _get_trigger_holdoff(self) -> bool:
-        fwversion = self.get_idn()['firmware']
-        if not isinstance(fwversion, str) or LooseVersion(fwversion) < \
-                LooseVersion(self._trigger_holdoff_min_fw_version):
+        fwversion = self.get_idn()["firmware"]
+        if not isinstance(fwversion, str) or version.parse(fwversion) < version.parse(
+            self._trigger_holdoff_min_fw_version
+        ):
             return False
 
         # we want to check if the 26h bit (zero indexed) is high or not
@@ -359,13 +360,16 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
         return bool(bin(output)[-27])
 
     def _set_trigger_holdoff(self, value: bool) -> None:
-        fwversion = self.get_idn()['firmware']
-        if not isinstance(fwversion, str) or LooseVersion(fwversion) < \
-                LooseVersion(self._trigger_holdoff_min_fw_version):
-            raise RuntimeError(f"Alazar 9373 requires at least firmware "
-                               f"version {self._trigger_holdoff_min_fw_version}"
-                               f" for trigger holdoff support. "
-                               f"You have version {fwversion}")
+        fwversion = self.get_idn()["firmware"]
+        if not isinstance(fwversion, str) or version.parse(fwversion) < version.parse(
+            self._trigger_holdoff_min_fw_version
+        ):
+            raise RuntimeError(
+                f"Alazar 9373 requires at least firmware "
+                f"version {self._trigger_holdoff_min_fw_version}"
+                f" for trigger holdoff support. "
+                f"You have version {fwversion}"
+            )
         current_value = self._read_register(58)
 
         if value is True:
@@ -384,3 +388,11 @@ class AlazarTech_ATS9373(AlazarTech_ATS):
             disable_mask = ~np.uint32(1 << 26)
             new_value = current_value & disable_mask
         self._write_register(58, int(new_value))
+
+
+class AlazarTech_ATS9373(AlazarTechATS9373):
+    """
+    Alias for backwards compatibility. Will eventually be deprecated and removed
+    """
+
+    pass
