@@ -1,12 +1,15 @@
-import numpy as np
-from typing import Any, Tuple, Dict, Union
+from typing import Any, Dict, Tuple, Union
 
-from qcodes import (
-    VisaInstrument, InstrumentChannel, Parameter, ParameterWithSetpoints
+import numpy as np
+
+from qcodes.instrument import InstrumentChannel, VisaInstrument
+from qcodes.parameters import (
+    Parameter,
+    ParameterWithSetpoints,
+    ParamRawDataType,
+    create_on_off_val_mapping,
 )
-from qcodes.instrument.parameter import ParamRawDataType
-from qcodes.utils.validators import Enum, Numbers, Arrays, Ints
-from qcodes.utils.helpers import create_on_off_val_mapping
+from qcodes.validators import Arrays, Enum, Ints, Numbers
 
 
 class FrequencyAxis(Parameter):
@@ -24,7 +27,13 @@ class FrequencyAxis(Parameter):
         self._npts: Parameter = npts
 
     def get_raw(self) -> ParamRawDataType:
-        return np.linspace(self._start(), self._stop(), self._npts())
+        start_val = self._start()
+        stop_val = self._stop()
+        npts_val = self._npts()
+        assert start_val is not None
+        assert stop_val is not None
+        assert npts_val is not None
+        return np.linspace(start_val, stop_val, npts_val)
 
 
 class Trace(ParameterWithSetpoints):
