@@ -3,22 +3,19 @@
 import logging
 import time
 from functools import partial
-from typing import Optional, Sequence, Dict, Tuple, Any, Union, List
+from typing import Any, Dict, List, Optional, Sequence, Tuple, Union
 
 import pyvisa as visa
 from pyvisa.resources.serial import SerialInstrument
 
-from qcodes.instrument.channel import (ChannelList, InstrumentChannel,
-                                       MultiChannelInstrumentParameter)
-from qcodes.instrument.visa import VisaInstrument
-from qcodes.instrument.base import Instrument
-from qcodes.instrument.parameter import ParamRawDataType
-from qcodes.utils import validators as vals
+from qcodes import validators as vals
+from qcodes.instrument import ChannelList, Instrument, InstrumentChannel, VisaInstrument
+from qcodes.parameters import MultiChannelInstrumentParameter, ParamRawDataType
 
 log = logging.getLogger(__name__)
 
 
-class QDacChannel(InstrumentChannel):
+class QDevQDacChannel(InstrumentChannel):
     """
     A single output channel of the QDac.
 
@@ -106,7 +103,7 @@ class QDacChannel(InstrumentChannel):
             self,
             update: Optional[bool] = False,
             params_to_skip_update: Optional[Sequence[str]] = None
-    ) -> Dict:
+    ) -> Dict[Any, Any]:
         update_currents = self._parent._update_currents and update
         if update and not self._parent._get_status_performed:
             self._parent._update_cache(readcurrents=update_currents)
@@ -121,7 +118,10 @@ class QDacChannel(InstrumentChannel):
         return snap
 
 
-class QDacMultiChannelParameter(MultiChannelInstrumentParameter):
+QDacChannel = QDevQDacChannel
+
+
+class QDevQDacMultiChannelParameter(MultiChannelInstrumentParameter):
     """
     The class to be returned by __getattr__ of the ChannelList. Here customised
     for fast multi-readout of voltages.
@@ -154,7 +154,10 @@ class QDacMultiChannelParameter(MultiChannelInstrumentParameter):
         return output
 
 
-class QDac(VisaInstrument):
+QDacMultiChannelParameter = QDevQDacMultiChannelParameter
+
+
+class QDevQDac(VisaInstrument):
     """
     Channelised driver for the QDev digital-analog converter QDac
 
@@ -194,7 +197,7 @@ class QDac(VisaInstrument):
         self._get_status_performed = False
         # This is the baud rate on power-up. It can be changed later but
         # you must start out with this value.
-        handle.baud_rate = 480600
+        handle.baud_rate = 460800
         handle.parity = visa.constants.Parity(0)
         handle.data_bits = 8
         self.set_terminator('\n')
@@ -223,17 +226,20 @@ class QDac(VisaInstrument):
         self.chan_range = range(1, 1 + self.num_chans)
         self.channel_validator = vals.Ints(1, self.num_chans)
 
-        channels = ChannelList(self, "Channels", QDacChannel,
-                               snapshotable=False,
-                               multichan_paramclass=QDacMultiChannelParameter)
+        channels = ChannelList(
+            self,
+            "Channels",
+            QDevQDacChannel,
+            snapshotable=False,
+            multichan_paramclass=QDevQDacMultiChannelParameter,
+        )
 
         for i in self.chan_range:
-            channel = QDacChannel(self, f'chan{i:02}', i)
+            channel = QDevQDacChannel(self, f"chan{i:02}", i)
             channels.append(channel)
             # Should raise valueerror if name is invalid (silently fails now)
-            self.add_submodule(f'ch{i:02}', channel)
-        channels.lock()
-        self.add_submodule('channels', channels)
+            self.add_submodule(f"ch{i:02}", channel)
+        self.add_submodule("channels", channels.to_channel_tuple())
 
         for board in range(6):
             for sensor in range(3):
@@ -269,7 +275,7 @@ class QDac(VisaInstrument):
             self,
             update: Optional[bool] = False,
             params_to_skip_update: Optional[Sequence[str]] = None
-    ) -> Dict:
+    ) -> Dict[Any, Any]:
         update_currents = self._update_currents and update is True
         if update:
             self._update_cache(readcurrents=update_currents)
@@ -318,7 +324,7 @@ class QDac(VisaInstrument):
             # happen inside _rampvoltage
             self._rampvoltage(chan, fg, v_start, v_set, time)
         else:
-            v_dac = QDac._get_v_dac_from_v_exp(channel, v_set)
+            v_dac = QDevQDac._get_v_dac_from_v_exp(channel, v_set)
             # set the mode back to DC in case it had been changed
             # and then set the voltage
             self.write(f'wav {chan} 0 0 0;set {chan} {v_dac:.6f}')
@@ -342,16 +348,16 @@ class QDac(VisaInstrument):
     # commands.
     # Then we have the general relationship`v_exp = v_dac * attenuation`,
     @staticmethod
-    def _get_attenuation(channel: QDacChannel) -> float:
+    def _get_attenuation(channel: QDevQDacChannel) -> float:
         return 0.1 if channel.vrange.cache() == 1 else 1.0
 
     @staticmethod
-    def _get_v_dac_from_v_exp(channel: QDacChannel, v_exp: float) -> float:
-        return v_exp / QDac._get_attenuation(channel)
+    def _get_v_dac_from_v_exp(channel: QDevQDacChannel, v_exp: float) -> float:
+        return v_exp / QDevQDac._get_attenuation(channel)
 
     @staticmethod
-    def _get_v_exp_from_v_dac(channel: QDacChannel, v_dac: float) -> float:
-        return v_dac * QDac._get_attenuation(channel)
+    def _get_v_exp_from_v_dac(channel: QDevQDacChannel, v_dac: float) -> float:
+        return v_dac * QDevQDac._get_attenuation(channel)
 
     def _set_vrange(self, chan: int, switchint: int) -> None:
         """
@@ -370,10 +376,10 @@ class QDac(VisaInstrument):
         # for definitions.
         channel = self.channels[chan-1]
         if channel.vrange.cache() != switchint:
-            v_dac = QDac._get_v_dac_from_v_exp(channel, channel.v.cache())
+            v_dac = QDevQDac._get_v_dac_from_v_exp(channel, channel.v.cache())
             channel.vrange.cache.set(switchint)
             self._update_v_validator(channel, switchint)
-            channel.v.cache.set(QDac._get_v_exp_from_v_dac(channel, v_dac))
+            channel.v.cache.set(QDevQDac._get_v_exp_from_v_dac(channel, v_dac))
 
     def _get_vrange(self, chan: int) -> float:
         """
@@ -462,7 +468,7 @@ class QDac(VisaInstrument):
             channel.vrange.cache.set(v_range)
             self._update_v_validator(channel, v_range)
             channel.irange.cache.set(i_range)
-            channel.v.cache.set(QDac._get_v_exp_from_v_dac(channel, v_dac))
+            channel.v.cache.set(QDevQDac._get_v_exp_from_v_dac(channel, v_dac))
 
             chans_left.remove(chan)
 
@@ -475,7 +481,7 @@ class QDac(VisaInstrument):
             _ = param.get()
 
     @staticmethod
-    def _update_v_validator(channel: QDacChannel, v_range: int) -> None:
+    def _update_v_validator(channel: QDevQDacChannel, v_range: int) -> None:
         range = (-10.01, 10.01) if v_range == 0 else (-1.001, 1.001)
         channel.v.vals = vals.Numbers(*range)
 
@@ -569,10 +575,12 @@ class QDac(VisaInstrument):
             return
 
         if len(self._slopes) >= 8:
-            rampchans = ', '.join([str(c[0]) for c in self._slopes])
-            raise ValueError('Can not assign finite slope to more than ' +
-                             "8 channels. Assign 'Inf' to at least one of " +
-                             f'the following channels: {rampchans}')
+            rampchans = ", ".join(str(c[0]) for c in self._slopes)
+            raise ValueError(
+                "Can not assign finite slope to more than "
+                + "8 channels. Assign 'Inf' to at least one of "
+                + f"the following channels: {rampchans}"
+            )
 
         self._slopes.append((chan, slope))
         return
@@ -592,7 +600,7 @@ class QDac(VisaInstrument):
         Print the finite slopes assigned to channels
         """
         for sl in self._slopes:
-            print('Channel {}, slope: {} (V/s)'.format(sl[0], sl[1]))
+            print(f"Channel {sl[0]}, slope: {sl[1]} (V/s)")
 
     def _rampvoltage(
             self,
@@ -720,8 +728,8 @@ class QDac(VisaInstrument):
 
         # Print the channels
         for ii in range(self.num_chans):
-            line = 'Channel {} \n'.format(ii+1)
-            line += '    '
+            line = f"Channel {ii+1} \n"
+            line += "    "
             for pp in paramstoget[0]:
                 param = getattr(self.channels[ii], pp)
                 line += printdict[pp]
@@ -733,6 +741,14 @@ class QDac(VisaInstrument):
                 param = getattr(self.channels[ii], pp)
                 line += printdict[pp]
                 value = param.get_latest()
-                line += ': {}'.format(returnmap[pp][value])
-                line += '. '
+                line += f": {returnmap[pp][value]}"
+                line += ". "
             print(line)
+
+
+class QDac(QDevQDac):
+    """
+    Backwards compatibility alias for QDevQDac driver
+    """
+
+    pass
