@@ -10,33 +10,42 @@ import qcodes as qc
 import qcodes.dataset.descriptions.versioning.serialization as serial
 import qcodes.tests.dataset
 from qcodes import new_data_set, new_experiment
+from qcodes.dataset.data_set import load_by_counter, load_by_id, load_by_run_spec
 from qcodes.dataset.descriptions.dependencies import InterDependencies_
 from qcodes.dataset.descriptions.param_spec import ParamSpecBase
 from qcodes.dataset.descriptions.versioning.v0 import InterDependencies
 from qcodes.dataset.guids import parse_guid
-from qcodes.dataset.sqlite.connection import atomic_transaction, ConnectionPlus
+from qcodes.dataset.sqlite.connection import ConnectionPlus, atomic_transaction
 from qcodes.dataset.sqlite.database import (
-    connect, get_db_version_and_newest_available_version, initialise_database,
-    initialise_or_create_database_at)
+    connect,
+    get_db_version_and_newest_available_version,
+    initialise_database,
+    initialise_or_create_database_at,
+)
+
 # pylint: disable=unused-import
-from qcodes.dataset.sqlite.db_upgrades import (_latest_available_version,
-                                               get_user_version,
-                                               perform_db_upgrade_0_to_1,
-                                               perform_db_upgrade_1_to_2,
-                                               perform_db_upgrade_2_to_3,
-                                               perform_db_upgrade_3_to_4,
-                                               perform_db_upgrade_4_to_5,
-                                               perform_db_upgrade_5_to_6,
-                                               perform_db_upgrade_6_to_7,
-                                               perform_db_upgrade_7_to_8,
-                                               perform_db_upgrade,
-                                               set_user_version,
-                                               perform_db_upgrade_8_to_9)
+from qcodes.dataset.sqlite.db_upgrades import (
+    _latest_available_version,
+    get_user_version,
+    perform_db_upgrade,
+    perform_db_upgrade_0_to_1,
+    perform_db_upgrade_1_to_2,
+    perform_db_upgrade_2_to_3,
+    perform_db_upgrade_3_to_4,
+    perform_db_upgrade_4_to_5,
+    perform_db_upgrade_5_to_6,
+    perform_db_upgrade_6_to_7,
+    perform_db_upgrade_7_to_8,
+    perform_db_upgrade_8_to_9,
+    set_user_version,
+)
 from qcodes.dataset.sqlite.queries import get_run_description, update_GUIDs
-from qcodes.dataset.sqlite.query_helpers import is_column_in_table, one
-from qcodes.tests.common import error_caused_by
-from qcodes.dataset.data_set import (
-    load_by_counter, load_by_id, load_by_run_spec)
+from qcodes.dataset.sqlite.query_helpers import (
+    get_description_map,
+    is_column_in_table,
+    one,
+)
+from qcodes.tests.common import error_caused_by, skip_if_no_fixtures
 from qcodes.tests.dataset.conftest import temporarily_copied_DB
 
 fixturepath = os.sep.join(qcodes.tests.dataset.__file__.split(os.sep)[:-1])
@@ -72,16 +81,19 @@ def test_connect_upgrades_user_version(ver):
 
 @pytest.mark.parametrize('version', VERSIONS + (LATEST_VERSION_ARG,))
 def test_tables_exist(empty_temp_db, version):
-    conn = connect(qc.config["core"]["db_location"],
-                   qc.config["core"]["db_debug"],
-                   version=version)
-    cursor = conn.execute("select sql from sqlite_master"
-                          " where type = 'table'")
-    expected_tables = ['experiments', 'runs', 'layouts', 'dependencies']
+    conn = connect(
+        qc.config["core"]["db_location"], qc.config["core"]["db_debug"], version=version
+    )
+    query = """
+    SELECT sql FROM sqlite_master
+    WHERE type = 'table'
+    """
+    cursor = conn.execute(query)
+    expected_tables = ["experiments", "runs", "layouts", "dependencies"]
     rows = [row for row in cursor]
     assert len(rows) == len(expected_tables)
-    for row, expected_table in zip(rows, expected_tables):
-        assert expected_table in row['sql']
+    for (sql,), expected_table in zip(rows, expected_tables):
+        assert expected_table in sql
     conn.close()
 
 
@@ -124,10 +136,7 @@ def test_perform_actual_upgrade_0_to_1():
 
     dbname_old = os.path.join(v0fixpath, 'empty.db')
 
-    if not os.path.exists(dbname_old):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the "
-                    "https://github.com/QCoDeS/qcodes_generate_test_db/ repo")
+    skip_if_no_fixtures(dbname_old)
 
     with temporarily_copied_DB(dbname_old, debug=False, version=0) as conn:
 
@@ -153,9 +162,7 @@ def test_perform_actual_upgrade_1_to_2():
 
     dbname_old = os.path.join(v1fixpath, 'empty.db')
 
-    if not os.path.exists(dbname_old):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the legacy_DB_generation folder")
+    skip_if_no_fixtures(dbname_old)
 
     with temporarily_copied_DB(dbname_old, debug=False, version=1) as conn:
 
@@ -183,10 +190,7 @@ def test_perform_actual_upgrade_2_to_3_empty():
 
     dbname_old = os.path.join(v2fixpath, 'empty.db')
 
-    if not os.path.exists(dbname_old):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the "
-                    "https://github.com/QCoDeS/qcodes_generate_test_db/ repo")
+    skip_if_no_fixtures(dbname_old)
 
     with temporarily_copied_DB(dbname_old, debug=False, version=2) as conn:
 
@@ -213,10 +217,7 @@ def test_perform_actual_upgrade_2_to_3_empty_runs():
 
     dbname_old = os.path.join(v2fixpath, 'empty_runs.db')
 
-    if not os.path.exists(dbname_old):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the "
-                    "https://github.com/QCoDeS/qcodes_generate_test_db/ repo")
+    skip_if_no_fixtures(dbname_old)
 
     with temporarily_copied_DB(dbname_old, debug=False, version=2) as conn:
 
@@ -229,10 +230,7 @@ def test_perform_actual_upgrade_2_to_3_some_runs():
 
     dbname_old = os.path.join(v2fixpath, 'some_runs.db')
 
-    if not os.path.exists(dbname_old):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the"
-                    "https://github.com/QCoDeS/qcodes_generate_test_db/ repo")
+    skip_if_no_fixtures(dbname_old)
 
     with temporarily_copied_DB(dbname_old, debug=False, version=2) as conn:
 
@@ -323,10 +321,7 @@ def test_perform_upgrade_v2_v3_to_v4_fixes():
 
     dbname_old = os.path.join(v3fixpath, 'some_runs_upgraded_2.db')
 
-    if not os.path.exists(dbname_old):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the"
-                    " https://github.com/QCoDeS/qcodes_generate_test_db/ repo")
+    skip_if_no_fixtures(dbname_old)
 
     with temporarily_copied_DB(dbname_old, debug=False, version=3) as conn:
 
@@ -469,10 +464,7 @@ def test_perform_upgrade_v3_to_v4():
 
     dbname_old = os.path.join(v3fixpath, 'some_runs_upgraded_2.db')
 
-    if not os.path.exists(dbname_old):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the "
-                    "https://github.com/QCoDeS/qcodes_generate_test_db/ repo")
+    skip_if_no_fixtures(dbname_old)
 
     with temporarily_copied_DB(dbname_old, debug=False, version=3) as conn:
 
@@ -637,10 +629,7 @@ def test_perform_actual_upgrade_4_to_5(db_file):
     db_file += '.db'
     dbname_old = os.path.join(v4fixpath, db_file)
 
-    if not os.path.exists(dbname_old):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the "
-                    "https://github.com/QCoDeS/qcodes_generate_test_db/ repo")
+    skip_if_no_fixtures(dbname_old)
 
     with temporarily_copied_DB(dbname_old, debug=False, version=4) as conn:
         # firstly, assert the situation with 'snapshot' column of 'runs' table
@@ -662,10 +651,7 @@ def test_perform_actual_upgrade_5_to_6():
     db_file = 'empty.db'
     dbname_old = os.path.join(fixpath, db_file)
 
-    if not os.path.exists(dbname_old):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the "
-                    "https://github.com/QCoDeS/qcodes_generate_test_db/ repo")
+    skip_if_no_fixtures(dbname_old)
 
     with temporarily_copied_DB(dbname_old, debug=False, version=5) as conn:
         perform_db_upgrade_5_to_6(conn)
@@ -690,7 +676,7 @@ def test_perform_actual_upgrade_5_to_6():
             assert deser['version'] == 0
 
             desc = serial.from_json_to_current(json_str)
-            assert desc._version == 2
+            assert desc._version == 3
 
 
 def test_perform_upgrade_6_7():
@@ -699,10 +685,7 @@ def test_perform_upgrade_6_7():
     db_file = 'empty.db'
     dbname_old = os.path.join(fixpath, db_file)
 
-    if not os.path.exists(dbname_old):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the "
-                    "https://github.com/QCoDeS/qcodes_generate_test_db/ repo")
+    skip_if_no_fixtures(dbname_old)
 
     with temporarily_copied_DB(dbname_old, debug=False, version=6) as conn:
         perform_db_upgrade_6_to_7(conn)
@@ -716,10 +699,7 @@ def test_perform_actual_upgrade_6_to_7():
     db_file = 'some_runs.db'
     dbname_old = os.path.join(fixpath, db_file)
 
-    if not os.path.exists(dbname_old):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the "
-                    "https://github.com/QCoDeS/qcodes_generate_test_db/ repo")
+    skip_if_no_fixtures(dbname_old)
 
     with temporarily_copied_DB(dbname_old, debug=False, version=6) as conn:
         assert isinstance(conn, ConnectionPlus)
@@ -731,8 +711,10 @@ def test_perform_actual_upgrade_6_to_7():
             atomic_transaction(conn, no_of_runs_query), 'max(run_id)')
         assert no_of_runs == 10
 
-        columns = atomic_transaction(conn, "PRAGMA table_info(runs)").fetchall()
-        col_names = [col['name'] for col in columns]
+        c = atomic_transaction(conn, "PRAGMA table_info(runs)")
+        description = get_description_map(c)
+        columns = c.fetchall()
+        col_names = [col[description["name"]] for col in columns]
 
         assert 'captured_run_id' in col_names
         assert 'captured_counter' in col_names
@@ -765,19 +747,17 @@ def test_perform_actual_upgrade_6_to_newest_add_new_data():
     Insert new runs on top of existing runs upgraded and verify that they
     get the correct captured_run_id and captured_counter
     """
-    from qcodes.dataset.measurements import Measurement
-    from qcodes.instrument.parameter import Parameter
     import numpy as np
 
+    from qcodes.dataset.measurements import Measurement
+    from qcodes.parameters import Parameter
+
     fixpath = os.path.join(fixturepath, 'db_files', 'version6')
 
     db_file = 'some_runs.db'
     dbname_old = os.path.join(fixpath, db_file)
 
-    if not os.path.exists(dbname_old):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the "
-                    "https://github.com/QCoDeS/qcodes_generate_test_db/ repo")
+    skip_if_no_fixtures(dbname_old)
 
     with temporarily_copied_DB(dbname_old, debug=False, version=6) as conn:
         assert isinstance(conn, ConnectionPlus)
@@ -865,10 +845,7 @@ def test_perform_actual_upgrade_7_to_8(db_file):
     db_file += '.db'
     dbname_old = os.path.join(v7fixpath, db_file)
 
-    if not os.path.exists(dbname_old):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the "
-                    "https://github.com/QCoDeS/qcodes_generate_test_db/ repo")
+    skip_if_no_fixtures(dbname_old)
 
     with temporarily_copied_DB(dbname_old, debug=False, version=7) as conn:
 
@@ -895,17 +872,14 @@ def test_latest_available_version():
     assert _latest_available_version() == 9
 
 
-@pytest.mark.parametrize('version', VERSIONS)
+@pytest.mark.parametrize("version", VERSIONS[:-1])
 def test_getting_db_version(version):
 
     fixpath = os.path.join(fixturepath, 'db_files', f'version{version}')
 
     dbname = os.path.join(fixpath, 'empty.db')
 
-    if not os.path.exists(dbname):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the "
-                    "https://github.com/QCoDeS/qcodes_generate_test_db/ repo")
+    skip_if_no_fixtures(dbname)
 
     (db_v, new_v) = get_db_version_and_newest_available_version(dbname)
 
@@ -922,10 +896,7 @@ def test_perform_actual_upgrade_8_to_9(db_file):
     db_file += '.db'
     dbname_old = os.path.join(v8fixpath, db_file)
 
-    if not os.path.exists(dbname_old):
-        pytest.skip("No db-file fixtures found. You can generate test db-files"
-                    " using the scripts in the "
-                    "https://github.com/QCoDeS/qcodes_generate_test_db/ repo")
+    skip_if_no_fixtures(dbname_old)
 
     with temporarily_copied_DB(dbname_old, debug=False, version=8) as conn:
 
