@@ -4,16 +4,17 @@ from copy import deepcopy
 
 import pytest
 
+from qcodes.dataset.descriptions.dependencies import (
+    DependencyError,
+    InferenceError,
+    InterDependencies_,
+)
 from qcodes.dataset.descriptions.param_spec import ParamSpec, ParamSpecBase
-from qcodes.dataset.descriptions.dependencies import (DependencyError,
-                                                      InferenceError,
-                                                      InterDependencies_)
+from qcodes.dataset.descriptions.versioning.converters import new_to_old, old_to_new
 from qcodes.dataset.descriptions.versioning.v0 import InterDependencies
-from qcodes.dataset.descriptions.versioning.converters import (new_to_old, old_to_new)
 from qcodes.tests.common import error_caused_by
 
 
-
 def test_wrong_input_raises():
 
     for pspecs in [['p1', 'p2', 'p3'],
