@@ -1,5 +1,6 @@
 import pytest
-from qcodes.utils.helpers import DelegateAttributes
+
+from qcodes.utils import DelegateAttributes
 
 
 def test_delegate_dict():
