@@ -1,20 +1,33 @@
-from unittest import TestCase
-import numpy as np
+import logging
 import os
 import pickle
-import logging
+from unittest import TestCase
 
-from qcodes.data.location import FormatLocation
-from qcodes.data.data_array import DataArray
+import numpy as np
+import pandas as pd
+import xarray as xr
+
+from qcodes.data.data_array import DataArray, data_array_to_xarray_dictionary
+from qcodes.data.data_set import (
+    DataSet,
+    load_data,
+    new_data,
+    qcodes_dataset_to_xarray_dataset,
+    xarray_dataset_to_qcodes_dataset,
+)
 from qcodes.data.io import DiskIO
-from qcodes.data.data_set import load_data, new_data, DataSet
+from qcodes.data.location import FormatLocation
 from qcodes.logger.logger import LogCapture
 
-from .data_mocks import (MockFormatter, MatchIO,
-                         DataSet2D, DataSet1D,
-                         DataSetCombined, RecordingMockFormatter)
-
 from ..common import strip_qc
+from .data_mocks import (
+    DataSet1D,
+    DataSet2D,
+    DataSetCombined,
+    MatchIO,
+    MockFormatter,
+    RecordingMockFormatter,
+)
 
 
 class TestDataArray(TestCase):
@@ -279,6 +292,22 @@ class TestDataArray(TestCase):
         data.synced_index = 22
         self.assertEqual(data.fraction_complete(), 23 / 50)
 
+    def test_to_xarray(self):
+        data = DataArray(preset_data=[1, 2])
+        array_dict = data_array_to_xarray_dictionary(data)
+        xarray_dataarray = data.to_xarray()
+
+    def test_xarray_conversions(self):
+        da = DataSet1D(name="TestDataArray_test_xarray_conversions").x_set
+
+        xarray_dictionary = data_array_to_xarray_dictionary(da)
+
+        xarray_dataarray = da.to_xarray()
+        da_transformed = DataArray.from_xarray(xarray_dataarray)
+
+        for key in ["array_id", "unit", "label"]:
+            self.assertEqual(getattr(da, key), getattr(da_transformed, key))
+
 
 class TestLoadData(TestCase):
 
@@ -492,7 +521,8 @@ class TestDataSet(TestCase):
         empty_data = new_data(arrays=(), location=False)
         self.assertEqual(empty_data.fraction_complete(), 0.0)
 
-        data = DataSetCombined(location=False)
+        data = DataSetCombined(location=False,
+                               name="test_fraction_complete")
         self.assertEqual(data.fraction_complete(), 1.0)
 
         # alter only the measured arrays, check that only these are used
@@ -577,3 +607,51 @@ class TestDataSet(TestCase):
         m.remove_array('z')
         _ = m.__repr__()
         self.assertFalse('z' in m.arrays)
+
+    def test_xarray_conversions(self):
+        qd = DataSet1D(name="TestNewData_test_xarray_conversions")
+        xarray_data_set = qcodes_dataset_to_xarray_dataset(qd)
+        qd_transformed = xarray_dataset_to_qcodes_dataset(xarray_data_set)
+        m = qd.default_parameter_array()
+        mt = qd_transformed.default_parameter_array()
+
+        for key in ["name", "unit"]:
+            self.assertEqual(getattr(m, key), getattr(mt, key))
+        qd2 = DataSet2D(name="TestNewData_test_xarray_conversions")
+        xarray_data_set = qcodes_dataset_to_xarray_dataset(qd2)
+        qd2_transformed = xarray_dataset_to_qcodes_dataset(xarray_data_set)
+
+        m = qd2.default_parameter_array()
+        mt = qd2_transformed.default_parameter_array()
+        for key in ["name", "unit"]:
+            self.assertEqual(getattr(m, key), getattr(mt, key))
+
+        xds = qd.to_xarray()
+        qds = DataSet.from_xarray(xds)
+
+    def test_xarray_example_conversion(self):
+        times = pd.date_range("2000-01-01", "2000-1-31", name="time")
+        shape = (31, 3)
+        xarray_dataset = xr.Dataset(
+            {"tmin": (("time", "location"), np.random.rand(*shape)),
+                "tmax": (("time", "location"), np.random.rand(*shape)),
+             }, {"time": times, "location": ["IA", "IN", "IL"]},)
+
+        qd = DataSet.from_xarray(xarray_dataset)
+        xarray_dataset2 = qd.to_xarray()
+
+        self.assertEqual(qd.default_parameter_array().shape, xarray_dataset.tmin.shape)
+        self.assertEqual(list(xarray_dataset.coords.keys()), list(xarray_dataset2.coords.keys()))
+        self.assertEqual(list(xarray_dataset.data_vars.keys()), list(xarray_dataset2.data_vars.keys()))
+        self.assertEqual(xarray_dataset.tmin.shape, xarray_dataset2.tmin.shape)
+
+    def test_dataset_conversion_transpose_regression(self):
+        qd = DataSet2D(name="test")
+        qd.x_set.label = "X label"
+        qd.x_set.unit = "seconds"
+        ds = qd.to_xarray().transpose()
+        qdt = DataSet.from_xarray(ds)
+
+        self.assertEqual(qd.x_set.label, qdt.x_set.label)
+        self.assertEqual(qd.x_set.unit, qdt.x_set.unit)
+        self.assertEqual([a.name for a in qdt.z.set_arrays], ["y_set", "x_set"])
