@@ -5,13 +5,15 @@ instrument. Please note that `channel` in this context does not necessarily
 mean a physical instrument channel, but rather an instrument sub-module.
 """
 
-from typing import List, Union, Any, Dict, Callable, Optional
-import pytest
 import re
+from typing import Any, Callable, Dict, List, Optional, Union
 
-from qcodes import Instrument
+import pytest
+
+from qcodes.instrument import Instrument, InstrumentChannel
 from qcodes.instrument.channel import (
-    AutoLoadableInstrumentChannel, AutoLoadableChannelList, InstrumentChannel
+    AutoLoadableChannelList,
+    AutoLoadableInstrumentChannel,
 )
 
 
@@ -22,7 +24,7 @@ class MockBackendBase:
     expressions and on match the corresponding callable is called.
     """
     def __init__(self) -> None:
-        self._command_dict: Dict[str, Callable] = {}
+        self._command_dict: Dict[str, Callable[..., Any]] = {}
 
     def send(self, cmd: str) -> Any:
         """
@@ -76,9 +78,8 @@ class MockBackend(MockBackendBase):
                 lambda chn: self._greetings[chn] + " from channel " + str(chn),
             r":INST:CHN:ADD (\d), (.+)": self._add_channel,
             r":INST:CHN:DEL (\d)": self._channel_catalog.remove,
-            r":INST:CHN:CAT": lambda: ",".join([
-                str(i) for i in self._channel_catalog]),
-            r":INST:CHN(\d):GRT":  self._greetings.get
+            r":INST:CHN:CAT": lambda: ",".join(str(i) for i in self._channel_catalog),
+            r":INST:CHN(\d):GRT": self._greetings.get,
         }
 
     def _add_channel(self, chn: int, greeting: str)->None:
@@ -96,7 +97,7 @@ class SimpleTestChannel(AutoLoadableInstrumentChannel):
 
     @classmethod
     def _discover_from_instrument(
-            cls, parent: Instrument, **kwargs) -> List[dict]:
+            cls, parent: Instrument, **kwargs) -> List[Dict[Any, Any]]:
         """
         New channels need `name` and `channel` keyword arguments.
         """
@@ -124,7 +125,8 @@ class SimpleTestChannel(AutoLoadableInstrumentChannel):
 
     @classmethod
     def _get_new_instance_kwargs(
-            cls, parent: Optional[Instrument] = None, **kwargs) -> dict:
+            cls, parent: Optional[Instrument] = None, **kwargs
+    ) -> Dict[Any, Any]:
         """
         Find the smallest channel number not yet occupied. An optional keyword
         `greeting` is extracted from the kwargs. The default is "Hello"
