@@ -9,11 +9,11 @@ from numpy.testing import assert_allclose, assert_array_equal
 
 from qcodes import Instrument
 from qcodes.data.location import FormatLocation
-from qcodes.instrument.channel import ChannelList, ChannelTuple, InstrumentChannel
-from qcodes.instrument.parameter import Parameter
+from qcodes.instrument import ChannelList, ChannelTuple, InstrumentChannel
 from qcodes.loops import Loop
+from qcodes.parameters import Parameter
 from qcodes.tests.instrument_mocks import DummyChannel, DummyChannelInstrument
-from qcodes.utils.validators import Numbers
+from qcodes.validators import Numbers
 
 
 @pytest.fixture(scope='function', name='dci')
@@ -59,6 +59,18 @@ def _make_empty_instrument():
 class EmptyChannel(InstrumentChannel):
     pass
 
+
+def test_instrument_channel_label():
+    dci = DummyChannelInstrument(name="dci_with_labels", label="Instrument Label")
+    channel = DummyChannel(dci, "A_with_label", "A_wl", label="A with f@ncy label")
+    dci.add_submodule("A_with_label", channel)
+    channel = EmptyChannel(dci, "B_with_label", label="B with f@ncy label")
+    dci.add_submodule("B_with_label", channel)
+    assert dci.label == "Instrument Label"
+    assert dci.A_with_label.label == "A with f@ncy label"
+    assert dci.B_with_label.label == "B with f@ncy label"
+
+
 def test_channels_call_function(dci, caplog):
     """
     Test that dci.channels.some_function() calls
@@ -301,11 +313,13 @@ def test_channel_list_get_validator_not_locked_raised(dci_with_list):
     with pytest.raises(AttributeError, match="Cannot create a validator"):
         dci_with_list.channels.get_validator()
 
+
 def test_channel_tuple_index(dci):
 
     for i, chan in enumerate(dci.channels):
         assert dci.channels.index(chan) == i
 
+
 def test_channel_tuple_snapshot(dci):
     snapshot = dci.channels.snapshot()
     assert snapshot["snapshotable"] is False
@@ -327,6 +341,7 @@ def test_channel_tuple_snapshot_enabled(empty_instrument):
     assert len(snapshot.keys()) == 3
     assert "channels" in snapshot.keys()
 
+
 def test_channel_tuple_dir(dci):
 
     dir_list = dir(dci.channels)
@@ -337,6 +352,7 @@ def test_channel_tuple_dir(dci):
     for param in dci.channels[0].parameters.values():
         assert param.short_name in dir_list
 
+
 def test_clear_channels(dci_with_list):
     channels = dci_with_list.channels
     channels.clear()
@@ -377,6 +393,7 @@ def test_channel_list_lock_twice(dci_with_list):
     # locking twice should be a no op
     channels.lock()
 
+
 def test_remove_tupled_channel(dci_with_list):
     channel_tuple = tuple(
         DummyChannel(dci_with_list, f"Chan{C}", C)
@@ -511,6 +528,7 @@ def test_set_element_locked_raises(dci_with_list):
         dci_with_list.channels[0] = dci_with_list.channels[1]
     assert dci_with_list.channels[0] is not dci_with_list.channels[1]
 
+
 @settings(suppress_health_check=(HealthCheck.function_scoped_fixture,))
 @given(myindexs=hst.lists(elements=hst.integers(0, 7), min_size=2))
 def test_access_channels_by_name(dci, myindexs):
@@ -523,6 +541,7 @@ def test_access_channels_by_name(dci, myindexs):
     for chan, chanindex in zip(mychans, myindexs):
         assert chan.name == f'dci_Chan{names[chanindex]}'
 
+
 def test_channels_contain(dci):
     names = ("A", "B", "C", "D", "E", "F", "G", "H")
     channels = tuple(DummyChannel(dci, "Chan" + name, name) for name in names)
@@ -809,6 +828,23 @@ def test_get_attr_on_empty_channellist_works_as_expected(empty_instrument):
         _ = empty_instrument.channels.temperature
 
 
+def test_channel_tuple_call_method_basic_test(dci):
+    result = dci.channels.turn_on()
+    assert result is None
+
+
+def test_channel_tuple_call_method_called_as_expected(dci, mocker):
+
+    for channel in dci.channels:
+        channel.turn_on = mocker.MagicMock(return_value=1)
+
+    result = dci.channels.turn_on("bar")
+    # We never return the result (same for Function)
+    assert result is None
+    for channel in dci.channels:
+        channel.turn_on.assert_called_with("bar")
+
+
 def _verify_multiparam_data(data):
     assert 'multi_setpoint_param_this_setpoint_set' in data.arrays.keys()
     assert_array_equal(
