@@ -1,28 +1,26 @@
-import pytest
-from contextlib import contextmanager
+import json
+import os
 import tempfile
 import warnings
-from pathlib import Path
-import os
-from typing import Optional
-import json
+from contextlib import contextmanager
 from io import StringIO
+from pathlib import Path
+from typing import Optional
+
+import pytest
+from ruamel.yaml import YAML
 
 import qcodes
-import qcodes.utils.validators as validators
-from qcodes.utils.helpers import get_qcodes_path
-from qcodes.utils.deprecate import assert_deprecated, deprecation_message
-from qcodes.instrument.parameter import DelegateParameter
-from qcodes import Instrument
-from qcodes.station import (
-    Station, ValidationWarning, update_config_schema, SCHEMA_PATH)
-from qcodes.instrument.parameter import Parameter
-from qcodes.monitor.monitor import Monitor
-from qcodes.tests.instrument_mocks import (
-    DummyInstrument)
+from qcodes import validators
+from qcodes.instrument import Instrument
+from qcodes.monitor import Monitor
+from qcodes.parameters import DelegateParameter, Parameter
+from qcodes.station import SCHEMA_PATH, Station, ValidationWarning, update_config_schema
 from qcodes.tests.common import default_config
-from qcodes.utils.helpers import NumpyJSONEncoder
-from qcodes.utils.helpers import YAML
+from qcodes.tests.instrument_mocks import DummyInstrument
+from qcodes.utils import NumpyJSONEncoder, QCoDeSDeprecationWarning, get_qcodes_path
+from qcodes.utils.deprecate import deprecation_message
+
 from .common import DumyPar
 
 
@@ -179,6 +177,9 @@ def test_snapshot():
     station.add_component(parameter)
     parameter_snapshot = parameter.snapshot()
 
+    excluded_parameter = Parameter('excluded_parameter', snapshot_exclude=True)
+    station.add_component(excluded_parameter)
+
     component = DumyPar('component')
     component.metadata['smth'] = 'in the way she moves'
     station.add_component(component)
@@ -196,6 +197,7 @@ def test_snapshot():
     assert ['instrument'] == list(snapshot['instruments'].keys())
     assert instrument_snapshot == snapshot['instruments']['instrument']
 
+    # the list should not contain the excluded parameter
     assert ['parameter'] == list(snapshot['parameters'].keys())
     assert parameter_snapshot == snapshot['parameters']['parameter']
 
@@ -260,8 +262,20 @@ def config_file_context(file_content):
         yield str(filename)
 
 
-@pytest.fixture
-def example_station_config():
+@contextmanager
+def config_files_context(file_content1, file_content2):
+    with tempfile.TemporaryDirectory() as tmpdirname:
+        filename1 = Path(tmpdirname, 'station_config1.yaml')
+        with filename1.open('w') as f:
+            f.write(file_content1)
+        filename2 = Path(tmpdirname, 'station_config2.yaml')
+        with filename2.open('w') as f:
+            f.write(file_content2)
+        yield [str(filename1), str(filename2)]
+
+
+@pytest.fixture(name="example_station_config")
+def _make_example_station_config():
     """
     Returns path to temp yaml file with station config.
     """
@@ -271,7 +285,7 @@ instruments:
   lakeshore:
     type: qcodes.instrument_drivers.Lakeshore.Model_336.Model_336
     enable_forced_reconnect: true
-    address: GPIB::2::65535::INSTR
+    address: GPIB::2::INSTR
     init:
       visalib: '{sims_path}lakeshore_model336.yaml@sim'
   mock_dac:
@@ -293,7 +307,7 @@ def test_dynamic_reload_of_file(example_station_config):
     st = Station(config_file=example_station_config)
     mock_dac = st.load_instrument('mock_dac')
     assert 'ch1' in mock_dac.parameters
-    with open(example_station_config, 'r') as f:
+    with open(example_station_config) as f:
         filedata = f.read().replace('ch1', 'gate1')
     with open(example_station_config, 'w') as f:
         f.write(filedata)
@@ -312,8 +326,8 @@ def station_config_has_been_loaded(st: Station) -> bool:
     return st.config is not None
 
 
-@pytest.fixture
-def example_station(example_station_config):
+@pytest.fixture(name="example_station")
+def _make_example_station(example_station_config):
     return Station(config_file=example_station_config)
 
 
@@ -562,7 +576,7 @@ instruments:
 
 class InstrumentWithNameAsNotFirstArgument(Instrument):
     def __init__(self, first_arg, name):
-        super(InstrumentWithNameAsNotFirstArgument, self).__init__(name)
+        super().__init__(name)
         self._first_arg = first_arg
 
 
@@ -741,11 +755,11 @@ instruments:
     driver: qcodes.tests.instrument_mocks
     type: DummyChannelInstrument
     """)
-    with assert_deprecated(
-        deprecation_message(
-            'use of the "driver"-keyword in the station configuration file',
-            alternative='the "type"-keyword instead, prepending the driver value'
-                        ' to it')):
+    message = deprecation_message(
+        'use of the "driver"-keyword in the station configuration file',
+        alternative='the "type"-keyword instead, prepending the driver value to it',
+    )
+    with pytest.warns(QCoDeSDeprecationWarning, match=message):
         st.load_instrument('mock')
 
 
@@ -760,11 +774,11 @@ instruments:
       ch1:
         limits: -10, 10
     """)
-    with assert_deprecated(
-        deprecation_message(
-            'use of a comma separated string for the limits keyword',
-            alternative='an array like "[lower_lim, upper_lim]"')
-    ):
+    message = deprecation_message(
+        "use of a comma separated string for the limits keyword",
+        alternative=r'an array like "\[lower_lim, upper_lim\]"',
+    )
+    with pytest.warns(QCoDeSDeprecationWarning, match=message):
         st.load_instrument('mock')
 
 
@@ -796,3 +810,102 @@ def test_config_validation_comprehensive_config():
     Station(config_file=os.path.join(
         get_qcodes_path(), 'dist', 'tests', 'station', 'example.station.yaml')
     )
+
+
+def test_load_all_instruments_raises_on_both_only_names_and_only_types_passed(
+        example_station
+):
+    with pytest.raises(
+        ValueError,
+        match="It is an error to supply both ``only_names`` "
+              "and ``only_types`` arguments.",
+    ):
+        example_station.load_all_instruments(only_names=(), only_types=())
+
+
+def test_load_all_instruments_no_args(example_station):
+    all_instruments_in_config = {"lakeshore", "mock_dac", "mock_dac2"}
+
+    loaded_instruments = example_station.load_all_instruments()
+
+    assert set(loaded_instruments) == all_instruments_in_config
+
+    for instrument in all_instruments_in_config:
+        assert instrument in example_station.components
+        assert Instrument.exist(instrument)
+
+
+def test_load_all_instruments_only_types(example_station):
+    all_dummy_instruments = {"mock_dac", "mock_dac2"}
+
+    loaded_instruments = example_station.load_all_instruments(
+        only_types=("DummyInstrument",)
+    )
+
+    assert set(loaded_instruments) == all_dummy_instruments
+
+    for instrument in all_dummy_instruments:
+        assert instrument in example_station.components
+        assert Instrument.exist(instrument)
+
+    other_instruments = (
+            set(example_station.config["instruments"].keys())
+            - all_dummy_instruments
+    )
+
+    for instrument in other_instruments:
+        assert instrument not in example_station.components
+        assert not Instrument.exist(instrument)
+
+
+def test_load_all_instruments_only_names(example_station):
+    instruments_to_load = {"lakeshore", "mock_dac"}
+
+    loaded_instruments = example_station.load_all_instruments(
+        only_names=instruments_to_load
+    )
+
+    assert set(loaded_instruments) == instruments_to_load
+
+    for instrument in loaded_instruments:
+        assert instrument in example_station.components
+        assert Instrument.exist(instrument)
+
+    other_instruments = (
+            set(example_station.config["instruments"].keys())
+            - instruments_to_load
+    )
+
+    for instrument in other_instruments:
+        assert instrument not in example_station.components
+        assert not Instrument.exist(instrument)
+
+
+def test_load_all_instruments_without_config_raises():
+    station = Station()
+    with pytest.raises(ValueError, match="Station has no config"):
+        station.load_all_instruments()
+
+
+def test_station_config_created_with_multiple_config_files():
+
+    test_config1 = f"""
+        instruments:
+          mock_dac1:
+            type: qcodes.tests.instrument_mocks.DummyInstrument
+            enable_forced_reconnect: true
+            init:
+              gates: {{"ch1", "ch2"}}
+            parameters:
+              ch1:
+                monitor: true
+    """
+    test_config2 = f"""
+        instruments:
+          mock_dac2:
+            type: qcodes.tests.instrument_mocks.DummyInstrument
+    """
+    with config_files_context(
+            test_config1, test_config2
+    ) as file_list:
+        assert station_config_has_been_loaded(Station(config_file=file_list))
